from seven_jd.jd.api.base import RestApi

class IsvAddisvlogRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.account = None
			self.clientIp = None
			self.operationTime = None
			self.operationContent = None
			self.useIsvAppkey = None
			self.reqjosUrl = None
			self.touchNumber = None
			self.touchFiles = None

		def getapiname(self):
			return 'jingdong.isv.addisvlog'

			








from seven_jd.jd.api.base import RestApi

class EclpMasterInsertShopRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.isvShopNo = None
			self.spSourceNo = None
			self.deptNo = None
			self.spShopNo = None
			self.shopName = None
			self.contacts = None
			self.phone = None
			self.address = None
			self.email = None
			self.fax = None
			self.afterSaleContacts = None
			self.afterSaleAddress = None
			self.afterSalePhone = None
			self.bdOwnerNo = None
			self.reserve1 = None
			self.reserve2 = None
			self.reserve3 = None
			self.reserve4 = None
			self.reserve5 = None
			self.reserve6 = None
			self.reserve7 = None
			self.reserve8 = None
			self.reserve9 = None
			self.reserve10 = None
			self.outstoreRules = None

		def getapiname(self):
			return 'jingdong.eclp.master.insertShop'

			








from seven_jd.jd.api.base import RestApi

class PopBeanSendBeanRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.requestId = None
			self.beanNum = None
			self.accountId = None
			self.accountCode = None
			self.sendWay = None
			self.sendCode = None
			self.accountType = None
			self.context = None
			self.planId = None
			self.rfId = None
			self.open_id_buyer = None
			self.xid_buyer = None

		def getapiname(self):
			return 'jingdong.pop.bean.sendBean'

			








from seven_jd.jd.api.base import RestApi

class PromoActivityListOperatelogRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.activityId = None
			self.skuId = None
			self.skuIdList = None
			self.operateLevel = None
			self.operateList = None
			self.operatorName = None
			self.multiActivityId = None
			self.storeId = None
			self.pageSize = None
			self.startIndex = None

		def getapiname(self):
			return 'jingdong.promo.activity.list.operatelog'

			








# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2023-04-03 14:45:50
:LastEditTime: 2023-04-03 15:30:09
:LastEditors: HuangJingCan
:Description: 
"""
from seven_jd.jd.api.base import sign


class appinfo(object):
    def __init__(self, appkey, secret):
        self.appkey = appkey
        self.secret = secret


def getDefaultAppInfo():
    pass


def setDefaultAppInfo(appkey, secret):
    default = appinfo(appkey, secret)
    global getDefaultAppInfo
    getDefaultAppInfo = lambda: default



from seven_jd.jd.api.base import RestApi

class PopOrderGetRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.order_state = None
			self.optional_fields = None
			self.order_id = None

		def getapiname(self):
			return 'jingdong.pop.order.get'

			








from seven_jd.jd.api.base import RestApi

class SellerCouponWritePushCouponRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.port = None
			self.requestId = None
			self.pin = None
			self.distrTime = None
			self.couponId = None
			self.uuid = None
			self.open_id_buyer = None
			self.xid_buyer = None

		def getapiname(self):
			return 'jingdong.seller.coupon.write.pushCoupon'

			








from seven_jd.jd.api.base import RestApi

class EclpExceptionQueryExceptionListRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.deptNo = None
			self.orderNos = None
			self.isvOrderNos = None
			self.orderType = None
			self.bizType = None
			self.createTimeStart = None
			self.createTimeEnd = None
			self.pageNo = None
			self.pageSize = None
			self.errCode = None

		def getapiname(self):
			return 'jingdong.eclp.exception.queryExceptionList'

			








from seven_jd.jd.api.base import RestApi

class PopPresellMyPresellServiceAddQualification4AppRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.appName = None
			self.ip = None
			self.bu_Id = None
			self.systemKey = None
			self.ua = None
			self.pin = None
			self.sku = None

		def getapiname(self):
			return 'jingdong.pop.presell.MyPresellService.addQualification4App'

			








from seven_jd.jd.api.base import RestApi

class VcItemAttrAppliesFindRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.ware_group_id = None
			self.category = None
			self.begin_apply_time = None
			self.end_apply_time = None
			self.state = None
			self.public_name = None
			self.offset = None
			self.page_size = None

		def getapiname(self):
			return 'jingdong.vc.item.attr.applies.find'

			








from seven_jd.jd.api.base import RestApi


class CrmModelGetRequest(RestApi):
    def __init__(self, domain='gw.api.360buy.com', port=80):
        """
			"""
        RestApi.__init__(self, domain, port)

    def getapiname(self):
        return 'jingdong.crm.model.get'



from seven_jd.jd.api.base import RestApi

class LotteryActivityCreateRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.client = None
			self.awardsActivityInfo = None

		def getapiname(self):
			return 'jingdong.lottery.activity.create'

			
	

class Client(object):
		def __init__(self):
			"""
			"""
			self.appName = None
			self.appId = None
			self.channel = None
			self.requestIP = None
			self.timestamp = None


class AwardsRuleDTO(object):
		def __init__(self):
			"""
			"""
			self.awardsImgUrl = None
			self.awardsLevel = None
			self.awardsContent = None
			self.awardsQuatity = None
			self.lotteryMode = None
			self.lotteryNum = None
			self.awardsName = None


class AwardsDTO(object):
		def __init__(self):
			"""
			"""
			self.awardsRuleDTOList = None
			self.awardsType = None


class AwardsActivityInfo(object):
		def __init__(self):
			"""
			"""
			self.applyEndTime = None
			self.activityEndTime = None
			self.awardsDTOList = None
			self.test = None
			self.name = None
			self.activityStartTime = None
			self.type = None
			self.applyStartTime = None
			self.activityImgUrl = None
			self.worth = None








from seven_jd.jd.api.base import RestApi

class PrintingPrintDataSensitivePullDataRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.param1 = None

		def getapiname(self):
			return 'jingdong.printing.printData.sensitivePullData'

			
	

class Attribute1(object):
		def __init__(self):
			"""
			"""
			self.orderNo = None
			self.ewPrintData = None
			self.wayBillNo = None


class Param1(object):
		def __init__(self):
			"""
			"""
			self.objectId = None
			self.parameters = None
			self.cpCode = None
			self.ewPrintDataInfos = None








from seven_jd.jd.api.base import RestApi

class EclpOrderAsynAddOrderRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.isvUUID = None
			self.isvSource = None
			self.shopNo = None
			self.bdOwnerNo = None
			self.departmentNo = None
			self.warehouseNo = None
			self.shipperNo = None
			self.salesPlatformOrderNo = None
			self.salePlatformSource = None
			self.salesPlatformCreateTime = None
			self.soType = None
			self.consigneeName = None
			self.consigneeMobile = None
			self.consigneePhone = None
			self.consigneeEmail = None
			self.expectDate = None
			self.addressProvince = None
			self.addressCity = None
			self.addressCounty = None
			self.addressTown = None
			self.consigneeAddress = None
			self.consigneePostcode = None
			self.receivable = None
			self.consigneeRemark = None
			self.orderMark = None
			self.thirdWayBill = None
			self.packageMark = None
			self.businessType = None
			self.destinationCode = None
			self.destinationName = None
			self.sendWebsiteCode = None
			self.sendWebsiteName = None
			self.sendMode = None
			self.receiveMode = None
			self.appointDeliveryTime = None
			self.insuredPriceFlag = None
			self.insuredValue = None
			self.insuredFee = None
			self.thirdPayment = None
			self.monthlyAccount = None
			self.shipment = None
			self.sellerRemark = None
			self.thirdSite = None
			self.customsStatus = None
			self.customerName = None
			self.invoiceTitle = None
			self.invoiceContent = None
			self.goodsType = None
			self.goodsLevel = None
			self.customsPort = None
			self.billType = None
			self.orderPrice = None
			self.orderBatchNo = None
			self.orderBatchQty = None
			self.transactionSource = None
			self.countrycode = None
			self.goodsNo = None
			self.price = None
			self.quantity = None
			self.serialNo = None
			self.printName = None

		def getapiname(self):
			return 'jingdong.eclp.order.asynAddOrder'

			








from seven_jd.jd.api.base import RestApi

class PopOrderFbpSearchRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.startDate = None
			self.endDate = None
			self.orderState = None
			self.page = None
			self.pageSize = None
			self.colType = None
			self.optionalFields = None
			self.orderId = None
			self.sortType = None
			self.dateType = None
			self.storeId = None
			self.cky2 = None

		def getapiname(self):
			return 'jingdong.pop.order.fbp.search'

			








from seven_jd.jd.api.base import RestApi

class OpenApplyAppointmentRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.cityName = None
			self.sourceType = None
			self.ip = None
			self.appKey = None
			self.tenantCode = None
			self.provinceName = None
			self.productName = None

		def getapiname(self):
			return 'jingdong.open.applyAppointment'

			








from seven_jd.jd.api.base import RestApi

class WareProductUpdateQueryRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.sku_status = None
			self.start_SaleDate = None
			self.end_SaleDate = None
			self.thirdCid = None
			self.scrollId = None

		def getapiname(self):
			return 'jingdong.ware.product.update.query'

			








from seven_jd.jd.api.base import RestApi

class WriteInteractUserCollectSinglePrizeRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.appName = None
			self.appId = None
			self.clientChannel = None
			self.activityId = None
			self.userPin = None
			self.prizeRuleId = None
			self.businessId = None
			self.type = None
			self.channel = None
			self.open_id_buyer = None
			self.xid_buyer = None

		def getapiname(self):
			return 'jingdong.write.interact.user.collectSinglePrize'

			








from seven_jd.jd.api.base import RestApi


class DirectlyZeusTaskCompleteRequest(RestApi):
    def __init__(self, domain='gw.api.360buy.com', port=80):
        """
			"""
        RestApi.__init__(self, domain, port)
        self.source = None
        self.openId = None
        self.encrypt = None

    def getapiname(self):
        return 'jingdong.directly.zeus.task.complete'



# -*- coding: utf-8 -*-
import time
import pytz
import datetime
import json
import itertools
import mimetypes
import hashlib
import requests
from urllib import parse
from seven_jd import jd

P_APPKEY = "app_key"
P_API = "method"
P_ACCESS_TOKEN = "access_token"
P_VERSION = "v"
P_FORMAT = "format"
P_TIMESTAMP = "timestamp"
P_SIGN = "sign"
P_JSON_PARAM_KEY = "360buy_param_json"

P_CODE = 'code'
P_SUB_CODE = 'sub_code'
P_MSG = 'msg'
P_SUB_MSG = 'sub_msg'

N_REST = '/routerjson'


def sign(secret, parameters):
    if hasattr(parameters, "items"):
        keys = parameters.keys()
        # keys.sort()
        keys = sorted(keys)
        parameters = "%s%s%s" % (secret, str().join('%s%s' % (key, parameters[key]) for key in keys), secret)
    return hashlib.md5(parameters.encode('utf-8')).hexdigest().upper()


def mixStr(pstr):
    if (isinstance(pstr, str)):
        return pstr
    elif (isinstance(pstr, bytes)):
        return pstr.encode('utf-8')
    else:
        return str(pstr)


class FileItem(object):
    def __init__(self, filename=None, content=None):
        self.filename = filename
        self.content = content


class MultiPartForm(object):
    """Accumulate the data to be used when posting a form."""
    def __init__(self):
        self.form_fields = []
        self.files = []
        self.boundary = "PYTHON_SDK_BOUNDARY"
        return

    def get_content_type(self):
        return 'multipart/form-data; boundary=%s' % self.boundary

    def add_field(self, name, value):
        """Add a simple field to the form data."""
        self.form_fields.append((name, str(value)))
        return

    def add_file(self, fieldname, filename, fileHandle, mimetype=None):
        """Add a file to be uploaded."""
        body = fileHandle.read()
        if mimetype is None:
            mimetype = mimetypes.guess_type(filename)[0] or 'application/octet-stream'
        self.files.append((mixStr(fieldname), mixStr(filename), mixStr(mimetype), mixStr(body)))
        return

    def __str__(self):
        """Return a string representing the form data, including attached files."""
        # Build a list of lists, each containing "lines" of the
        # request.  Each part is separated by a boundary string.
        # Once the list is built, return a string where each
        # line is separated by '\r\n'.
        parts = []
        part_boundary = '--' + self.boundary

        # Add the form fields
        parts.extend([
            part_boundary,
            'Content-Disposition: form-data; name="%s"' % name,
            'Content-Type: text/plain; charset=UTF-8',
            '',
            value,
        ] for name, value in self.form_fields)

        # Add the files to upload
        parts.extend(
            [part_boundary,
             'Content-Disposition: file; name="%s"; filename="%s"' % \
                 (field_name, filename),
             'Content-Type: %s' % content_type,
             'Content-Transfer-Encoding: binary',
             '',
             body,
             ]
            for field_name, filename, content_type, body in self.files
        )

        # Flatten the list and add closing boundary marker,
        # then return CR+LF separated data
        flattened = list(itertools.chain(*parts))
        flattened.extend(('--' + self.boundary + '--', ''))
        return '\r\n'.join(flattened)


class JdException(Exception):
    def __init__(self):
        self.errorcode = None
        self.message = None
        self.subcode = None
        self.submsg = None
        self.application_host = None
        self.service_host = None

    def __str__(self, *args, **kwargs):
        sb = "errorcode=" + mixStr(self.errorcode) + \
             " message=" + mixStr(self.message) + \
             " subcode=" + mixStr(self.subcode) + \
             " submsg=" + mixStr(self.submsg) + \
             " application_host=" + mixStr(self.application_host) + \
             " service_host=" + mixStr(self.service_host)
        return sb


class RequestException(Exception):
    pass


class RestApi(object):
    def __init__(self, domain='gw.api.360buy.net', port=80):
        self.__domain = domain
        self.__port = port
        self.__httpmethod = "POST"
        if (jd.getDefaultAppInfo()):
            self.__app_key = jd.getDefaultAppInfo().appkey
            self.__secret = jd.getDefaultAppInfo().secret

    def get_request_header(self):
        return {
            'Content-type': 'application/x-www-form-urlencoded',
            "Cache-Control": "no-cache",
            "Connection": "Keep-Alive",
        }

    def set_app_info(self, appinfo):
        self.__app_key = appinfo.appkey
        self.__secret = appinfo.secret

    def getapiname(self):
        return ""

    def get_version(self):
        return '2.0'

    def getMultipartParas(self):
        return []

    def getTranslateParas(self):
        return {}

    def _check_requst(self):
        pass

    def process_with_url_before_request(self, url):
        pass

    def getResponse(self, accessToken=None, version=None, timeout=30, ssl=False):
        hour_diff = time.localtime()[3] - datetime.datetime.now(tz=pytz.timezone('UTC')).hour
        if 0 < hour_diff < 10:
            zone_str = '+0' + str(hour_diff) + '00'
        elif hour_diff > 10:
            zone_str = '+' + str(hour_diff) + '00'
        elif 0 > hour_diff > -10:
            zone_str = '-0' + str(-hour_diff) + '00'
        else:
            zone_str = '-' + str(-hour_diff) + '00'
        time_str = time.strftime("%Y-%m-%d %H:%M:%S.000", time.localtime()) + zone_str
        sys_parameters = {
            P_APPKEY: self.__app_key,
            P_VERSION: self.get_version() if version is None else version,
            P_API: self.getapiname(),
            P_TIMESTAMP: time_str,
        }
        if accessToken is not None:
            sys_parameters[P_ACCESS_TOKEN] = accessToken
        if not self.__domain.startswith('http'):
            url = 'https://' if ssl else 'http://'
            url += self.__domain
        else:
            url = self.__domain
        if not url.endswith(N_REST) and not url.endswith(N_REST + '/'):
            url = url[:-1] if url.endswith('/') else url
            url = url + N_REST
        self.process_with_url_before_request(url)
        application_parameter = self.getApplicationParameters()
        sys_parameters[P_JSON_PARAM_KEY] = json.dumps(application_parameter, ensure_ascii=False, default=lambda value: value.__dict__)
        sys_parameters[P_SIGN] = sign(self.__secret, sys_parameters)
        if self.__httpmethod == 'POST':
            return requests.post(url, data=sys_parameters, timeout=timeout).json()
        url = url + "?" + parse.urlencode(sys_parameters)
        return requests.get(url, timeout=timeout).json()

    def getApplicationParameters(self):
        application_parameter = {}
        for key, value in self.__dict__.items():
            # for key, value in self.__dict__.iteritems():
            if (not key.startswith("__") and key not in self.getMultipartParas() and not key.startswith("_RestApi__") and value is not None):
                if key.startswith("_"):
                    application_parameter[key[1:]] = value
                else:
                    application_parameter[key] = value
        translate_parameter = self.getTranslateParas()
        # for key, value in application_parameter.iteritems():
        for key in application_parameter:
            if key in translate_parameter:
                application_parameter[translate_parameter[key]] = application_parameter[key]
                del application_parameter[key]
        return application_parameter


from seven_jd.jd.api.base import RestApi

class EclpCoCreateWbOrderRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.orderNo = None
			self.deptNo = None
			self.senderNickName = None
			self.senderName = None
			self.senderMobile = None
			self.senderPhone = None
			self.senderProvince = None
			self.senderCity = None
			self.senderCounty = None
			self.senderTown = None
			self.senderProvinceName = None
			self.senderCityName = None
			self.senderCountyName = None
			self.senderTownName = None
			self.senderAddress = None
			self.receiverNickName = None
			self.receiverName = None
			self.receiverMobile = None
			self.receiverPhone = None
			self.receiverProvince = None
			self.receiverCity = None
			self.receiverCounty = None
			self.receiverTown = None
			self.receiverProvinceName = None
			self.receiverCityName = None
			self.receiverCountyName = None
			self.receiverTownName = None
			self.remark = None
			self.grossWeight = None
			self.grossVolume = None
			self.createTime = None
			self.createUser = None
			self.receivable = None
			self.isCod = None
			self.vehicleTypeName = None
			self.vehicleTypeNo = None
			self.vehicleQty = None
			self.expressItemName = None
			self.expressItemQty = None
			self.signReceiptFlag = None
			self.deliveryReceiptFlag = None
			self.deliveryIntoWarehouse = None
			self.loadFlag = None
			self.unloadFlag = None
			self.receiptFlag = None
			self.fcFlag = None
			self.guaranteeValue = None
			self.pickupBeginTime = None
			self.pickupEndTime = None
			self.bussinessType = None
			self.deliveryType = None
			self.senderCompany = None
			self.receiverCompany = None
			self.receiverAddress = None
			self.warehouseCode = None
			self.projectName = None
			self.actualSpId = None
			self.coldChainOn = None
			self.temptureNum = None
			self.qingzhenOn = None
			self.yiwuranOn = None
			self.inStorageNo = None
			self.inStorageTime = None
			self.inStorageRemark = None
			self.heavyUpstair = None
			self.wayBillCode = None
			self.spId = None
			self.saleOrderNo = None
			self.packageServiceOn = None
			self.deliveryMthd = None
			self.providerCode = None
			self.packageNo = None
			self.clientNo = None
			self.orderType = None
			self.siteCollect = None
			self.siteDelivery = None
			self.quarantineCert = None
			self.selfCollectSiteId = None
			self.selfDeliverySiteId = None
			self.expectedArrivalStartTime = None
			self.expectedArrivalEndTime = None
			self.vehicleOrderNo = None
			self.messageSign = None
			self.checkPreSort = None
			self.receiverNameSplit = None
			self.receiverCompanySplit = None
			self.receiverMobileSplit = None
			self.receiverPhoneSplit = None
			self.receiverProvinceNameSplit = None
			self.receiverProvinceSplit = None
			self.receiverCityNameSplit = None
			self.receiverCitySplit = None
			self.receiverCountyNameSplit = None
			self.receiverCountySplit = None
			self.receiverTownNameSplit = None
			self.receiverTownSplit = None
			self.receiverAddressSplit = None
			self.expectedArrivalStartTimeSplit = None
			self.expectedArrivalEndTimeSplit = None
			self.orderNoSplit = None
			self.expressItemNameSplit = None
			self.grossVolumeSplit = None
			self.grossWeightSplit = None
			self.expressItemQtySplit = None
			self.temptureNumSplit = None
			self.quarantineCertSplit = None
			self.deliveryIntoWarehouseSplit = None
			self.inStorageNoSplit = None
			self.inStorageTimeSplit = None
			self.inStorageRemarkSplit = None
			self.loadFlagSplit = None
			self.unloadFlagSplit = None
			self.remarkSplit = None
			self.packageModelNosSplit = None
			self.qingzhenOnSplit = None
			self.yiwuranOnSplit = None
			self.receiverNickNameSplit = None
			self.guaranteeValueSplit = None
			self.heavyUpstairSplit = None
			self.hospitalServicesYYSplit = None
			self.isvOrderAmount = None
			self.tracker = None
			self.deliveryMode = None
			self.warehouseServiceType = None
			self.homeDeliveryOn = None
			self.siteCode = None
			self.referCancelDate = None
			self.rebackConfluenceOn = None
			self.expressDeliveryOn = None
			self.expectPickupDate = None
			self.expectDeliveryDate = None
			self.warehousePlatformName = None
			self.temporaryStorage = None
			self.predictReceiptDate = None
			self.extendFieldStr = None
			self.peaceMindReceive = None
			self.backInfoOn = None
			self.backName = None
			self.backMobile = None
			self.backPhone = None
			self.backProvinceName = None
			self.backCityName = None
			self.backCountyName = None
			self.backTownName = None
			self.backAddress = None
			self.importFlag = None
			self.fileWithCargo = None
			self.hospitalServicesYY = None
			self.param = None

		def getapiname(self):
			return 'jingdong.eclp.co.createWbOrder'

			








from seven_jd.jd.api.base import RestApi

class TemplateWriteUpdateRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.bottomContent = None
			self.headContent = None
			self.id = None
			self.name = None
			self.mobileBottomContent = None
			self.mobileHeadContent = None

		def getapiname(self):
			return 'jingdong.template.write.update'

			








from seven_jd.jd.api.base import RestApi

class EclpStockQueryWarehouseStockOrderFlowByGroupRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.startDate = None
			self.endDate = None
			self.deptNo = None
			self.warehouseNo = None
			self.goodsNo = None
			self.isvGoodsNo = None
			self.orderType = None
			self.bizType = None

		def getapiname(self):
			return 'jingdong.eclp.stock.queryWarehouseStockOrderFlowByGroup'

			








from seven_jd.jd.api.base import RestApi

class SelfOperationShopSearchApiServiceSearchRecomJsfServiceGetSkuListRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.keyword = None
			self.promoId = None
			self.pageNo = None
			self.pageSize = None

		def getapiname(self):
			return 'jingdong.self.operation.shop.search.api.service.SearchRecomJsfService.getSkuList'

			








from seven_jd.jd.api.base import RestApi

class EclpPoAddPoOrderRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.spPoOrderNo = None
			self.deptNo = None
			self.referenceOrder = None
			self.inboundRemark = None
			self.buyer = None
			self.logicParam = None
			self.supplierNo = None
			self.sellerSaleOrder = None
			self.saleOrder = None
			self.orderMark = None
			self.billType = None
			self.acceptUnQcFlag = None
			self.boxFlag = None
			self.entirePrice = None
			self.boxNo = None
			self.boxGoodsNo = None
			self.boxGoodsQty = None
			self.boxSerialNo = None
			self.boxIsvGoodsNo = None
			self.poReturnMode = None
			self.customsInfo = None
			self.poType = None
			self.billOfLading = None
			self.receiveLevel = None
			self.multiReceivingFlag = None
			self.waybillNo = None
			self.isvOutWarehouse = None
			self.bizType = None
			self.waitBoxDetailFlag = None
			self.unitFlag = None
			self.serialDetailMapJson = None
			self.serialNoScopeMapJson = None
			self.allowLackFlag = None
			self.isUpdate = None
			self.sellerOrderType = None
			self.customField = None
			self.sellerWarehouseNo = None
			self.whNo = None
			self.soNo = None
			self.deptGoodsNo = None
			self.isvGoodsNo = None
			self.numApplication = None
			self.goodsStatus = None
			self.barCodeType = None
			self.sidCheckout = None
			self.unitPrice = None
			self.totalPrice = None
			self.qualityCheckRate = None
			self.batAttrListJson = None
			self.orderLine = None
			self.isvLotattrs = None
			self.checkLotattrs = None
			self.goodsPrice = None
			self.warehousingFlag = None
			self.isvGoodsUnit = None

		def getapiname(self):
			return 'jingdong.eclp.po.addPoOrder'

			








from seven_jd.jd.api.base import RestApi

class SellerPromotionV2GetPromoLimitRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.ip = None
			self.port = None
			self.category_id = None
			self.start_time = None
			self.end_time = None

		def getapiname(self):
			return 'jingdong.seller.promotion.v2.getPromoLimit'

			








from seven_jd.jd.api.base import RestApi

class SkuReadSearchSkuListRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.wareId = None
			self.skuId = None
			self.skuStatuValue = None
			self.maxStockNum = None
			self.minStockNum = None
			self.endCreatedTime = None
			self.endModifiedTime = None
			self.startCreatedTime = None
			self.startModifiedTime = None
			self.outId = None
			self.colType = None
			self.itemNum = None
			self.wareTitle = None
			self.orderFiled = None
			self.orderType = None
			self.pageNo = None
			self.page_size = None
			self.valid = None
			self.key = None
			self.value = None
			self.cn = None
			self.field = None

		def getapiname(self):
			return 'jingdong.sku.read.searchSkuList'

			








from seven_jd.jd.api.base import RestApi

class EclpRtwAcceptReturnOrderRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.deliveryNo = None
			self.receiptNo = None
			self.packageCodes = None
			self.sourceNo = None
			self.ownerNo = None
			self.billType = None
			self.warehouseNo = None
			self.tenantId = None
			self.skuNo = None
			self.skuName = None
			self.expectedQty = None
			self.isvLotattrs = None
			self.checkLotattrs = None

		def getapiname(self):
			return 'jingdong.eclp.rtw.acceptReturnOrder'

			








from seven_jd.jd.api.base import RestApi

class EclpSpareQueryTransOrderRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.deptName = None
			self.orderType = None
			self.destWarehouseNo = None
			self.sellerName = None
			self.sellerNo = None
			self.pageSize = None
			self.startTime = None
			self.startWarehouseNo = None
			self.endTime = None
			self.type = None
			self.pageNum = None
			self.deptNo = None

		def getapiname(self):
			return 'jingdong.eclp.spare.queryTransOrder'

			








from seven_jd.jd.api.base import RestApi

class EclpIbAddOutsideMainRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.outsideSource = None
			self.selfLiftCode = None
			self.warehouseNoIn = None
			self.isvOutsideNo = None
			self.shipperNo = None
			self.deptNo = None
			self.warehouseNoOut = None
			self.goodsNo = None
			self.planNum = None
			self.batAttrListJson = None

		def getapiname(self):
			return 'jingdong.eclp.ib.addOutsideMain'

			








from seven_jd.jd.api.base import RestApi

class SensitiveEditRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.secretKey = None
			self.g = None
			self.cat = None
			self.contextWhite = None
			self.vendor = None
			self.brand = None
			self.extendMap = None
			self.source = None
			self.time = None
			self.word = None

		def getapiname(self):
			return 'jingdong.sensitive.edit'

			








from seven_jd.jd.api.base import RestApi

class MktSmartstrategyIntelligentisvSubmitISVPlanRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.targetThirdCateIds = None
			self.planName = None
			self.targetSecondCateIds = None
			self.targetFirstCateIds = None
			self.multiChannels = None
			self.pin = None
			self.pullNewer = None
			self.planBeginTime = None
			self.repurchase = None
			self.putKey = None
			self.catePopStrategy = None
			self.planEndTime = None
			self.campus = None

		def getapiname(self):
			return 'jingdong.mkt.smartstrategy.intelligentisv.submitISVPlan'

			








# -*- coding:utf-8 -*-
from seven_jd.jd.security.tde.tde_exceptions import MalformedException

default_kdf_algo = "HmacSHA256"
default_kid_algo = "MD5"
default_certdigest_algo = "SHA-256"
default_token_sign_algo = "HmacSHA256"
default_token_verify_algo = "SHA256withRSA"
default_character = "UTF-8"
default_dkey_len = 16
default_keyid_len = 16
default_cipherblk_len = 16
min_salt_len = 16
# 500 ms for default time out
http_timeout = 5000
# times for default reties
http_retry_count = 2
# default delta value for token expiration
token_exp_delta = 2592000000

TMS_PROD_TOKEN_PUB_KEY = '''
-----BEGIN PUBLIC KEY-----\n
MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA3/Y3RW2mCS2+h/wdRB\n
LbjqJJI61NbWkErnWYbgZZ8woinlIyur2A6KhoCUs0SPOrJVP65Cv+6OJnPCzr5\n
gCUb1C1i1HTPRMyPuvjOnlS8Llp5t0DCCSZdcu3UKsJwDC5d0/z+lBj9YNfUew/\n
C3GhMNvPWPIv6iWlXaG2jPNtsXFuFr/kCJXZVqOmJQ6BO3X2PaV05QJEz/xszvi\n
zpws6df1QN0Ol5dQpeCr5NMBVpxojBG1RGcfchJJ8D1dVYqt0BozD6BBhGrusfb\n
KwnBIrQpZZalxzlpCFTbf/6jdrm8fdMI8hymU3tx60PyxUiFi03jaO9/IkfLRc8U\n
n2uYYrWQIDAQAB\n
-----END PUBLIC KEY-----
'''

TMS_PROD_TOKEN_CERT = '''-----BEGIN CERTIFICATE-----\n
            MIIEcDCCA1igAwIBAgIJAKCBMSvIHNiEMA0GCSqGSIb3DQEBBQUAMIGAMQswCQYD\n
            VQQGEwJDTjEQMA4GA1UECBMHQmVpamluZzEQMA4GA1UEBxMHQmVpamluZzEPMA0G\n
            A1UEChMGSkQuQ09NMQwwCgYDVQQLEwNKT1MxEzARBgNVBAMTCmpvcy5qZC5jb20x\n
            GTAXBgkqhkiG9w0BCQEWCmpvc0BqZC5jb20wIBcNMTkwMzE1MDQ1NTM2WhgPMjA1\n
            OTAzMDUwNDU1MzZaMIGAMQswCQYDVQQGEwJDTjEQMA4GA1UECBMHQmVpamluZzEQ\n
            MA4GA1UEBxMHQmVpamluZzEPMA0GA1UEChMGSkQuQ09NMQwwCgYDVQQLEwNKT1Mx\n
            EzARBgNVBAMTCmpvcy5qZC5jb20xGTAXBgkqhkiG9w0BCQEWCmpvc0BqZC5jb20w\n
            ggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDf9jdFbaYJLb6H/B1EEtuO\n
            okkjrU1taQSudZhuBlnzCiKeUjK6vYDoqGgJSzRI86slU/rkK/7o4mc8LOvmAJRv\n
            ULWLUdM9EzI+6+M6eVLwuWnm3QMIJJl1y7dQqwnAMLl3T/P6UGP1g19R7D8LcaEw\n
            289Y8i/qJaVdobaM822xcW4Wv+QIldlWo6YlDoE7dfY9pXTlAkTP/GzO+LOnCzp1\n
            /VA3Q6Xl1Cl4Kvk0wFWnGiMEbVEZx9yEknwPV1Viq3QGjMPoEGEau6x9srCcEitC\n
            lllqXHOWkIVNt//qN2ubx90wjyHKZTe3HrQ/LFSIWLTeNo738iR8tFzxSfa5hitZ\n
            AgMBAAGjgegwgeUwHQYDVR0OBBYEFHYHDa2moq7nEccftSm3x72QBWWJMIG1BgNV\n
            HSMEga0wgaqAFHYHDa2moq7nEccftSm3x72QBWWJoYGGpIGDMIGAMQswCQYDVQQG\n
            EwJDTjEQMA4GA1UECBMHQmVpamluZzEQMA4GA1UEBxMHQmVpamluZzEPMA0GA1UE\n
            ChMGSkQuQ09NMQwwCgYDVQQLEwNKT1MxEzARBgNVBAMTCmpvcy5qZC5jb20xGTAX\n
            BgkqhkiG9w0BCQEWCmpvc0BqZC5jb22CCQCggTEryBzYhDAMBgNVHRMEBTADAQH/\n
            MA0GCSqGSIb3DQEBBQUAA4IBAQAr9qLL6qkNJjtcOzYM5afdyt+KBF9iwIcKG8ca\n
            NUPNXwOFnOFw/JBKR4svjafvV3rSGs7ZtVMmASLUhrtStwfJJvXV7tdyqC0p44u/\n
            sWK6SHoTNIHX+kXbzKrkwggqeTiUlHDTw60BP/mmbrYhIwOiTNvI247iWZ4IxxyD\n
            bpFULv0gBfTVuc/ATWrHTI2pT78lIectDgUCpTOAhQIvE0PLK9nZjrsSCvW7tRED\n
            PC+6KCPYQAzxmKvRRMCHXkAVeqb/0M6GEXBIT0aYEBHKdQ7s4g1VSGrbMUL5mQsA\n
            +3fYhR+QEhE8PboH5kVct1V9tiMpx7kymJQKVfNufC3FIlyr\n
            -----END CERTIFICATE-----'''


class CipherType(object):
    def __init__(self, id_param):
        self.id = id_param


class CipherTypes(object):
    __WEAK = CipherType(0)
    __REGULAR = CipherType(1)
    __LARGE = CipherType(2)

    @staticmethod
    def weak():
        return CipherTypes.__WEAK

    @staticmethod
    def regular():
        return CipherTypes.__REGULAR

    @staticmethod
    def large():
        return CipherTypes.__LARGE

    @staticmethod
    def from_value(value):
        if value == 0:
            return CipherTypes.__WEAK
        elif value == 1:
            return CipherTypes.__REGULAR
        elif value == 2:
            return CipherTypes.__LARGE
        raise MalformedException("unknown cipher type.")


class AlgoType(object):
    def __init__(self, id_param):
        self.id = id_param


class AlgoTypes(object):
    __AES_CBC_128 = AlgoType(4)

    @staticmethod
    def aes_cbc_128():
        return AlgoTypes.__AES_CBC_128

    @staticmethod
    def from_value(value):
        if value == 4:
            return AlgoTypes.__AES_CBC_128
        else:
            return None


class KeyType(object):
    def __init__(self, id_param):
        self.id = id_param


class KeyTypes(object):
    __AES = KeyType(0)

    @staticmethod
    def aes():
        return KeyTypes.__AES

    @staticmethod
    def from_value(value):
        if value is None:
            raise MalformedException('key type is null.')
        if value == 'AES':
            return KeyTypes.__AES
        else:
            return None


class KeyUsage(object):
    def __init__(self, id_param):
        self.id = id_param


class KeyUsages(object):
    __N = KeyUsage(-1)  # none
    __E = KeyUsage(0)  # encryption only
    __D = KeyUsage(1)  # decryption only
    __ED = KeyUsage(2)  # both

    @staticmethod
    def n():
        return KeyUsages.__N

    @staticmethod
    def e():
        return KeyUsages.__E

    @staticmethod
    def d():
        return KeyUsages.__D

    @staticmethod
    def ed():
        return KeyUsages.__ED

    @staticmethod
    def from_value(value):
        if value is None:
            raise MalformedException('key usage is null.')
        if value == 'N':
            return KeyUsages.__N
        elif value == 'E':
            return KeyUsages.__E
        elif value == 'D':
            return KeyUsages.__D
        elif value == 'ED':
            return KeyUsages.__ED
        raise MalformedException("unknown key usage.")


class KeyStatus(object):
    def __init__(self, id_param):
        self.id = id_param


class KeyStatuses(object):
    __ACTIVE = KeyStatus(0)
    __SUSPENDED = KeyStatus(1)
    __REVOKED = KeyStatus(2)

    @staticmethod
    def active():
        return KeyStatuses.__ACTIVE

    @staticmethod
    def suspended():
        return KeyStatuses.__SUSPENDED

    @staticmethod
    def revoked():
        return KeyStatuses.__REVOKED

    @staticmethod
    def from_value(value):
        if value == 0:
            return KeyStatuses.__ACTIVE
        elif value == 1:
            return KeyStatuses.__SUSPENDED
        elif value == 2:
            return KeyStatuses.__REVOKED
        raise MalformedException("unknown key status.")



from seven_jd.jd.api.base import RestApi

class LdopReceiveOrderInterceptRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.vendorCode = None
			self.deliveryId = None
			self.interceptReason = None
			self.cancelOperatorCodeType = None
			self.cancelTime = None
			self.cancelOperator = None

		def getapiname(self):
			return 'jingdong.ldop.receive.order.intercept'

			








from seven_jd.jd.api.base import RestApi

class GetDecryptPinRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.userPin = None
			self.appName = None
			self.appId = None
			self.requestIP = None
			self.time = None
			self.koiKey = None
			self.encryptPin = None

		def getapiname(self):
			return 'jingdong.getDecryptPin'

			








from seven_jd.jd.api.base import RestApi

class ApplyRepealSaveRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.data = None

		def getapiname(self):
			return 'jingdong.applyRepeal.save'

			








from seven_jd.jd.api.base import RestApi

class GroupMarketEditActivityRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.Language = None
			self.appName = None
			self.channel = None
			self.offerReceiveType = None
			self.autoSendTxt = None
			self.actEndTime = None
			self.attribute1 = None
			self.actName = None
			self.actStartTime = None
			self.attribute2 = None
			self.prepareTime = None
			self.id = None
			self.actImg = None
			self.actLink = None

		def getapiname(self):
			return 'jingdong.groupMarket.editActivity'

			








from seven_jd.jd.api.base import RestApi

class EclpSerialQueryPageSerialByBillNoRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.billNo = None
			self.billType = None
			self.pageNo = None
			self.pageSize = None
			self.queryType = None

		def getapiname(self):
			return 'jingdong.eclp.serial.queryPageSerialByBillNo'

			








from seven_jd.jd.api.base import RestApi

class WarehouseInboundOrderQueryListRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.pageIndex = None
			self.pageSize = None
			self.createTimeBegin = None
			self.createTimeEnd = None
			self.unpackingTimeBegin = None
			self.unpackingTimeEnd = None
			self.remark1 = None
			self.remark2 = None
			self.remark3 = None
			self.remark4 = None
			self.remark5 = None

		def getapiname(self):
			return 'jingdong.warehouse.inbound.order.query.list'

			








from seven_jd.jd.api.base import RestApi

class LdopOmsPickupAttachmentQueryRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.opeCode = None
			self.attachmentType = None
			self.busiId = None
			self.customerCode = None

		def getapiname(self):
			return 'jingdong.ldop.oms.pickup.attachment.query'

			








from seven_jd.jd.api.base import RestApi

class EclpTraceServiceJosOrderTraceByWaybillServiceRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.waybillId = None
			self.carrierCode = None
			self.role = None
			self.userId = None

		def getapiname(self):
			return 'jingdong.eclp.trace.service.jos.OrderTraceByWaybillService'

			








from seven_jd.jd.api.base import RestApi

class EclpRtsIsvRtsTransferRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.eclpRtsNo = None
			self.isvRtsNum = None
			self.rtsType = None
			self.deptNo = None
			self.deliveryMode = None
			self.warehouseNo = None
			self.supplierNo = None
			self.receiver = None
			self.receiverPhone = None
			self.email = None
			self.province = None
			self.city = None
			self.county = None
			self.town = None
			self.address = None
			self.createUser = None
			self.packFlag = None
			self.allowLack = None
			self.logicParam = None
			self.remark = None
			self.purchaser = None
			self.customField = None
			self.sellerBizType = None
			self.insuredPrice = None
			self.deptGoodsNo = None
			self.goodsName = None
			self.quantity = None
			self.realQuantity = None
			self.goodsStatus = None
			self.goodsLevel = None
			self.lotProductionBatchNo = None
			self.lotProductionDate = None
			self.lotSupplier = None
			self.batAttrListJson = None
			self.goodsPrice = None
			self.totalAmount = None
			self.isvGoodsNo = None
			self.orderLine = None

		def getapiname(self):
			return 'jingdong.eclp.rts.isvRtsTransfer'

			








# -*- coding:utf-8 -*-
import base64


def encode_to_string(param, encoding='US-ASCII'):
    return str(base64.b64encode(param), encoding)


def decode_to_string(param, encoding='US-ASCII'):
    return str(base64.b64decode(param), encoding)



from seven_jd.jd.api.base import RestApi

class JdAddressFromAddressGetRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.userid = None
			self.key = None
			self.provinceId = None
			self.cityId = None
			self.countryId = None
			self.townId = None
			self.address = None
			self.shipping = None

		def getapiname(self):
			return 'jingdong.JdAddressFromAddress.get'

			








from seven_jd.jd.api.base import RestApi

class EclpRtwUpdateRtwOrderRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.eclpRtwNo = None
			self.isvRtwNum = None
			self.ownerNo = None
			self.packageNo = None
			self.shipperName = None
			self.senderName = None
			self.senderTelPhone = None
			self.senderMobilePhone = None

		def getapiname(self):
			return 'jingdong.eclp.rtw.updateRtwOrder'

			








from seven_jd.jd.api.base import RestApi

class SellerCouponReadGetCouponCountRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.ip = None
			self.port = None
			self.couponId = None
			self.type = None
			self.grantType = None
			self.bindType = None
			self.grantWay = None
			self.name = None
			self.createMonth = None
			self.creatorType = None
			self.closed = None

		def getapiname(self):
			return 'jingdong.seller.coupon.read.getCouponCount'

			








from seven_jd.jd.api.base import RestApi

class SellerPromotionV2ListRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.ip = None
			self.port = None
			self.promo_id = None
			self.name = None
			self.type = None
			self.favor_mode = None
			self.begin_time = None
			self.end_time = None
			self.promo_status = None
			self.ware_id = None
			self.sku_id = None
			self.page = None
			self.pageS_size = None
			self.src_type = None
			self.start_id = None

		def getapiname(self):
			return 'jingdong.seller.promotion.v2.list'

			








from seven_jd.jd.api.base import RestApi

class EclpCoTransportReverseLasWaybillRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.deptNo = None
			self.orderNo = None
			self.salePlatform = None
			self.customerPin = None
			self.associateSoNo = None
			self.senderName = None
			self.senderMobile = None
			self.senderPhone = None
			self.senderAddress = None
			self.receiverName = None
			self.receiverMobile = None
			self.receiverPhone = None
			self.receiverAddress = None
			self.isFragile = None
			self.pickupReturnReason = None
			self.isGuarantee = None
			self.guaranteeValue = None
			self.isDoorToDoorRecycle = None
			self.weight = None
			self.length = None
			self.width = None
			self.height = None
			self.packageName = None
			self.packageQty = None
			self.productSku = None
			self.lasDisassemble = None
			self.lasBale = None
			self.thirdCategoryNo = None

		def getapiname(self):
			return 'jingdong.eclp.co.transportReverseLasWaybill'

			








from seven_jd.jd.api.base import RestApi

class MarketToolCouponApiServiceCouponWriteOuterServiceCloseCouponRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.couponId = None
			self.appName = None
			self.ip = None
			self.appId = None

		def getapiname(self):
			return 'jingdong.market.tool.coupon.api.service.CouponWriteOuterService.closeCoupon'

			








from seven_jd.jd.api.base import RestApi

class EclpOrderAddDeclareOrderCustomsRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.platformId = None
			self.platformName = None
			self.appType = None
			self.logisticsNo = None
			self.billSerialNo = None
			self.billNo = None
			self.freight = None
			self.insuredFee = None
			self.netWeight = None
			self.weight = None
			self.packNo = None
			self.worth = None
			self.goodsName = None
			self.orderNo = None
			self.shipper = None
			self.shipperAddress = None
			self.shipperTelephone = None
			self.shipperCountry = None
			self.consigneeCountry = None
			self.consigneeProvince = None
			self.consigneeCity = None
			self.consigneeDistrict = None
			self.consingee = None
			self.consigneeAddress = None
			self.consigneeTelephone = None
			self.buyerIdType = None
			self.buyerIdNumber = None
			self.customsId = None
			self.customsCode = None
			self.deptNo = None
			self.isvSource = None
			self.pattern = None
			self.isvUUID = None
			self.platformType = None
			self.salesPlatformCreateTime = None
			self.postType = None
			self.istax = None
			self.logisticsCode = None
			self.logisticsName = None
			self.isDelivery = None
			self.ebpCode = None
			self.ebpName = None
			self.ebcCode = None
			self.ebcName = None
			self.ebpCiqCode = None
			self.ebpCiqName = None
			self.ebcCiqCode = None
			self.ebcCiqName = None
			self.spSoNo = None

		def getapiname(self):
			return 'jingdong.eclp.order.addDeclareOrderCustoms'

			








from seven_jd.jd.api.base import RestApi

class MiniappApiActivityMiniAppActivityApiRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.activityMsg = None
			self.name = None
			self.startTime = None
			self.endTime = None
			self.activityUuid = None
			self.scene = None

		def getapiname(self):
			return 'jingdong.miniapp.api.activity.MiniAppActivityApi'

			








from seven_jd.jd.api.base import RestApi

class EclpGoodsUpdateGoodsInfoRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.goodsNo = None
			self.spGoodsNo = None
			self.barcodes = None
			self.abbreviation = None
			self.brandNo = None
			self.brandName = None
			self.manufacturer = None
			self.produceAddress = None
			self.standard = None
			self.color = None
			self.size = None
			self.sizeDefinition = None
			self.grossWeight = None
			self.netWeight = None
			self.length = None
			self.width = None
			self.height = None
			self.batch = None
			self.cheapGift = None
			self.quality = None
			self.expensive = None
			self.luxury = None
			self.breakable = None
			self.liquid = None
			self.consumables = None
			self.abnormal = None
			self.imported = None
			self.health = None
			self.temperature = None
			self.temperatureCeil = None
			self.temperatureFloor = None
			self.humidity = None
			self.humidityCeil = None
			self.humidityFloor = None
			self.movable = None
			self.service3g = None
			self.sample = None
			self.odor = None
			self.sex = None
			self.precious = None
			self.mixedBatch = None
			self.reserve1 = None
			self.reserve2 = None
			self.reserve3 = None
			self.reserve4 = None
			self.reserve5 = None
			self.reserve6 = None
			self.reserve7 = None
			self.reserve8 = None
			self.reserve9 = None
			self.reserve10 = None
			self.fashionNo = None
			self.goodsMess = None
			self.isvGoodsNo = None
			self.deptNo = None
			self.signType = None
			self.overseaPurchase = None
			self.qiRecord = None
			self.customRecord = None
			self.pattern = None
			self.ccProvider = None
			self.bondedArea = None
			self.sellerRecord = None
			self.batAttrIds = None
			self.needJDRecord = None
			self.modelNumber = None
			self.spe = None
			self.vatRate = None
			self.taxRate = None
			self.taxNumberPost = None
			self.postRate = None
			self.hsCode = None
			self.country = None
			self.qiCountry = None
			self.flag = None
			self.legalUnit1 = None
			self.legalAmount1 = None
			self.legalUnit2 = None
			self.legalAmount2 = None
			self.measurement = None
			self.qiMeasurement = None
			self.delivery = None
			self.storeProperty = None
			self.productCategory = None
			self.category = None
			self.approvalNo = None
			self.storage = None
			self.form = None
			self.type = None
			self.specification = None
			self.genericName = None
			self.dosage = None
			self.useMethods = None
			self.packingUnit = None
			self.efficacy = None
			self.manufactory = None
			self.price = None
			self.storeSaleFlag = None
			self.keyMaintenance = None
			self.specialDrugs = None
			self.marketingAuthorizationHolder = None
			self.boxRule = None
			self.warningDay = None
			self.regularAdventDay = None
			self.urgentAdventDay = None
			self.adventDay = None
			self.easyPollute = None
			self.muslim = None
			self.boxRegulations = None
			self.allowedDay = None
			self.sellerFirstCategory = None
			self.sellerSecondCategory = None
			self.sellerThirdCategory = None
			self.sellerFirstCategoryNo = None
			self.sellerSecondCategoryNo = None
			self.sellerThirdCategoryNo = None
			self.athletesUseCaution = None
			self.elecSupervisionCodeFlag = None
			self.hgsbys = None
			self.goodsUnit = None
			self.uniqueCode = None
			self.productLine = None
			self.isStandardInstrument = None
			self.isColdChain = None
			self.isDetachablePackage = None
			self.certificateNo = None
			self.businessTypeName = None
			self.ownerTypeName = None
			self.packageTypeName = None
			self.materialTypeName = None
			self.model = None
			self.clothingAttr = None
			self.clothingStyle = None
			self.clothingVersionType = None
			self.clothingSilhouette = None
			self.clothingThickness = None
			self.clothingWeek = None
			self.bodyParts = None
			self.styleSex = None
			self.listedBand = None
			self.expectListedTime = None
			self.fabric = None
			self.washing = None
			self.year = None
			self.productSeason = None
			self.afterSaleFlag = None
			self.productionLicenseNo = None
			self.transportTemperature = None
			self.boxUniqueCode = None
			self.auxiliary = None
			self.goodsNameEn = None
			self.minSaleQuantity = None
			self.minPackageQuantity = None
			self.packageInstruction = None
			self.texture = None
			self.substrate = None
			self.executiveStandard = None
			self.processTechnology = None
			self.allSerial = None
			self.isRcvDate = None
			self.renewPackage = None
			self.imgUrls = None
			self.warehouseInsured = None
			self.transportInsured = None
			self.isBillingSplit = None
			self.source = None
			self.medicineCategoryCode = None
			self.warehouseTransfer = None

		def getapiname(self):
			return 'jingdong.eclp.goods.updateGoodsInfo'

			








from seven_jd.jd.api.base import RestApi

class PopOrderEnSearchRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.start_date = None
			self.end_date = None
			self.order_state = None
			self.optional_fields = None
			self.page = None
			self.page_size = None
			self.sortType = None
			self.dateType = None

		def getapiname(self):
			return 'jingdong.pop.order.enSearch'

			








from seven_jd.jd.api.rest.VcItemExtPropsFindRequest import VcItemExtPropsFindRequest
from seven_jd.jd.api.rest.VcItemPrimaryPicAppliesFindRequest import VcItemPrimaryPicAppliesFindRequest
from seven_jd.jd.api.rest.VcItemPrimaryPicCreateRequest import VcItemPrimaryPicCreateRequest
from seven_jd.jd.api.rest.VcItemPrimaryPicUpdateRequest import VcItemPrimaryPicUpdateRequest
from seven_jd.jd.api.rest.MiniAppInsertVenderRequest import MiniAppInsertVenderRequest
from seven_jd.jd.api.rest.VcItemPrimaryPicGetRequest import VcItemPrimaryPicGetRequest
from seven_jd.jd.api.rest.VcItemProductsFindRequest import VcItemProductsFindRequest
from seven_jd.jd.api.rest.VcItemPrimaryPicApplyGetRequest import VcItemPrimaryPicApplyGetRequest
from seven_jd.jd.api.rest.CrmMemberSearchNewRequest import CrmMemberSearchNewRequest
from seven_jd.jd.api.rest.VcItemNewProductCreateRequest import VcItemNewProductCreateRequest
from seven_jd.jd.api.rest.VcItemProductApplyDeleteRequest import VcItemProductApplyDeleteRequest
from seven_jd.jd.api.rest.PopOrderCoupondetailRequest import PopOrderCoupondetailRequest
from seven_jd.jd.api.rest.VcItemProductAppliesFindRequest import VcItemProductAppliesFindRequest
from seven_jd.jd.api.rest.TemplateWriteUpdateRequest import TemplateWriteUpdateRequest
from seven_jd.jd.api.rest.PopOrderModifyVenderRemarkRequest import PopOrderModifyVenderRemarkRequest
from seven_jd.jd.api.rest.VcItemProductApplyGetRequest import VcItemProductApplyGetRequest
from seven_jd.jd.api.rest.FollowProductReadQueryForCountByProductIdRequest import FollowProductReadQueryForCountByProductIdRequest
from seven_jd.jd.api.rest.TemplateWriteDeleteRequest import TemplateWriteDeleteRequest
from seven_jd.jd.api.rest.TemplateWriteAddRequest import TemplateWriteAddRequest
from seven_jd.jd.api.rest.ComJdShopJzonecrmGwsJzoneShopJsfServiceGetShopInfoByVenderIdRequest import ComJdShopJzonecrmGwsJzoneShopJsfServiceGetShopInfoByVenderIdRequest
from seven_jd.jd.api.rest.PopPopCommentJsfServiceGetVenderCommentsForJosRequest import PopPopCommentJsfServiceGetVenderCommentsForJosRequest
from seven_jd.jd.api.rest.MfaInnerUserUnifiedAuthenticationRequest import MfaInnerUserUnifiedAuthenticationRequest
from seven_jd.jd.api.rest.VerifyAreaFourIdOpenReqRequest import VerifyAreaFourIdOpenReqRequest
from seven_jd.jd.api.rest.MktSmartstrategyIntelligentisvGetDeliveryChannelRequest import MktSmartstrategyIntelligentisvGetDeliveryChannelRequest
from seven_jd.jd.api.rest.PopPopCommentJsfServiceGetUserCommentVoucherRequest import PopPopCommentJsfServiceGetUserCommentVoucherRequest
from seven_jd.jd.api.rest.MktSmartstrategyIntelligentisvGetCouponBatchRequest import MktSmartstrategyIntelligentisvGetCouponBatchRequest
from seven_jd.jd.api.rest.VcItemPropsFindRequest import VcItemPropsFindRequest
from seven_jd.jd.api.rest.VcItemNewProductCreateV2Request import VcItemNewProductCreateV2Request
from seven_jd.jd.api.rest.VcItemCategoriesFindRequest import VcItemCategoriesFindRequest
from seven_jd.jd.api.rest.VcItemBrandsFindRequest import VcItemBrandsFindRequest
from seven_jd.jd.api.rest.MiniappBrandBenefitReportRequest import MiniappBrandBenefitReportRequest
from seven_jd.jd.api.rest.VcItemProductGetRequest import VcItemProductGetRequest
from seven_jd.jd.api.rest.MfaInnerValidateMsgCodeRequest import MfaInnerValidateMsgCodeRequest
from seven_jd.jd.api.rest.MfaInnerEliminateRiskRequest import MfaInnerEliminateRiskRequest
from seven_jd.jd.api.rest.ConvertFourAreaByDetailStrRequest import ConvertFourAreaByDetailStrRequest
from seven_jd.jd.api.rest.PopCrmGetCustomerPointsRequest import PopCrmGetCustomerPointsRequest
from seven_jd.jd.api.rest.PresaleOrderUpdateOrderGetPresaleOrderByPageRequest import PresaleOrderUpdateOrderGetPresaleOrderByPageRequest
from seven_jd.jd.api.rest.FollowProductComplexWriteFollowRequest import FollowProductComplexWriteFollowRequest
from seven_jd.jd.api.rest.RiskQueryServiceRequest import RiskQueryServiceRequest
from seven_jd.jd.api.rest.MfaInnerSendCodeToMobileRequest import MfaInnerSendCodeToMobileRequest
from seven_jd.jd.api.rest.UserGetUserInfoByXIdRequest import UserGetUserInfoByXIdRequest
from seven_jd.jd.api.rest.VcItemOldProductUpdateV2Request import VcItemOldProductUpdateV2Request
from seven_jd.jd.api.rest.VcItemSaleAttributeSettingsV1GetRequest import VcItemSaleAttributeSettingsV1GetRequest
from seven_jd.jd.api.rest.VcItemOldProductUpdateRequest import VcItemOldProductUpdateRequest
from seven_jd.jd.api.rest.UserGetUserInfoByOpenIdRequest import UserGetUserInfoByOpenIdRequest
from seven_jd.jd.api.rest.VenderShopcategoryFindShopCategoriesByVenderIdRequest import VenderShopcategoryFindShopCategoriesByVenderIdRequest
from seven_jd.jd.api.rest.ImgzoneCategoryQueryRequest import ImgzoneCategoryQueryRequest
from seven_jd.jd.api.rest.VenderCategoryGetFullValidCategoryResultByVenderIdRequest import VenderCategoryGetFullValidCategoryResultByVenderIdRequest
from seven_jd.jd.api.rest.YipOrderAddCartForeignRequest import YipOrderAddCartForeignRequest
from seven_jd.jd.api.rest.ImgzoneCategoryAddRequest import ImgzoneCategoryAddRequest
from seven_jd.jd.api.rest.ImgzoneUserinfoQueryRequest import ImgzoneUserinfoQueryRequest
from seven_jd.jd.api.rest.ImgzonePictureQueryRequest import ImgzonePictureQueryRequest
from seven_jd.jd.api.rest.VenderShopcategoryGetShopCategoryByCidRequest import VenderShopcategoryGetShopCategoryByCidRequest
from seven_jd.jd.api.rest.EliveLiveRoomJsfServiceRequest import EliveLiveRoomJsfServiceRequest
from seven_jd.jd.api.rest.ImgzonePictureUploadRequest import ImgzonePictureUploadRequest
from seven_jd.jd.api.rest.VasSubscribeGetByCodeRequest import VasSubscribeGetByCodeRequest
from seven_jd.jd.api.rest.LockCertsSaveRequest import LockCertsSaveRequest
from seven_jd.jd.api.rest.EdiRealtimeinventoryQueryRequest import EdiRealtimeinventoryQueryRequest
from seven_jd.jd.api.rest.ImgzoneImageUploadRequest import ImgzoneImageUploadRequest
from seven_jd.jd.api.rest.VcItemSpuTemplateGetRequest import VcItemSpuTemplateGetRequest
from seven_jd.jd.api.rest.PopCrmGetPointsDetailRequest import PopCrmGetPointsDetailRequest
from seven_jd.jd.api.rest.UstFlowDataStatisticOnlineRequest import UstFlowDataStatisticOnlineRequest
from seven_jd.jd.api.rest.VasSubscribeGetRequest import VasSubscribeGetRequest
from seven_jd.jd.api.rest.SensitiveEditRequest import SensitiveEditRequest
from seven_jd.jd.api.rest.SensitiveInvalidRequest import SensitiveInvalidRequest
from seven_jd.jd.api.rest.PopOrderSearchRequest import PopOrderSearchRequest
from seven_jd.jd.api.rest.PopCrmGetCouponInfoRequest import PopCrmGetCouponInfoRequest
from seven_jd.jd.api.rest.JosTokenSourceToOpenIdRequest import JosTokenSourceToOpenIdRequest
from seven_jd.jd.api.rest.GroupMarketCreateActivityRequest import GroupMarketCreateActivityRequest
from seven_jd.jd.api.rest.GroupMarketQueryChatGroupsRequest import GroupMarketQueryChatGroupsRequest
from seven_jd.jd.api.rest.VcGetpurchaserlistbypinRequest import VcGetpurchaserlistbypinRequest
from seven_jd.jd.api.rest.VcItemQualificationListFindRequest import VcItemQualificationListFindRequest
from seven_jd.jd.api.rest.VcGetrequisitiondetailbywareidRequest import VcGetrequisitiondetailbywareidRequest
from seven_jd.jd.api.rest.JzoneAddCartItemByPinRequest import JzoneAddCartItemByPinRequest
from seven_jd.jd.api.rest.VcItemDangergoodsGetRequest import VcItemDangergoodsGetRequest
from seven_jd.jd.api.rest.BatchAddSkuAddRequest import BatchAddSkuAddRequest
from seven_jd.jd.api.rest.PopCrmGetMemberInVenderRequest import PopCrmGetMemberInVenderRequest
from seven_jd.jd.api.rest.VcItemFeatureFindRequest import VcItemFeatureFindRequest
from seven_jd.jd.api.rest.VcItemModelFindRequest import VcItemModelFindRequest
from seven_jd.jd.api.rest.MktSmartstrategyIntelligentisvSubmitISVPlanRequest import MktSmartstrategyIntelligentisvSubmitISVPlanRequest
from seven_jd.jd.api.rest.PopCrmQueryCustomerGundogByVenderIdAndPinRequest import PopCrmQueryCustomerGundogByVenderIdAndPinRequest
from seven_jd.jd.api.rest.MktSmartstrategyIntelligentisvGetISVPlanEffectListRequest import MktSmartstrategyIntelligentisvGetISVPlanEffectListRequest
from seven_jd.jd.api.rest.PopOrderGetRequest import PopOrderGetRequest
from seven_jd.jd.api.rest.EdiPoDetailProGetRequest import EdiPoDetailProGetRequest
from seven_jd.jd.api.rest.EdiSdvStockinfoGetRequest import EdiSdvStockinfoGetRequest
from seven_jd.jd.api.rest.EdiSdvCustomerOrderSearchRequest import EdiSdvCustomerOrderSearchRequest
from seven_jd.jd.api.rest.MiniappIsvCreatedMiniAppExperVersionRequest import MiniappIsvCreatedMiniAppExperVersionRequest
from seven_jd.jd.api.rest.PopBeanSendBeanRequest import PopBeanSendBeanRequest
from seven_jd.jd.api.rest.MiniappIsvGetMiniAppDevVersionListRequest import MiniappIsvGetMiniAppDevVersionListRequest
from seven_jd.jd.api.rest.PopPlanAddBeanPlanRequest import PopPlanAddBeanPlanRequest
from seven_jd.jd.api.rest.MiniappIsvRevokeMiniAppCheckVersionRequest import MiniappIsvRevokeMiniAppCheckVersionRequest
from seven_jd.jd.api.rest.PopAccountGetAccountInfoRequest import PopAccountGetAccountInfoRequest
from seven_jd.jd.api.rest.MiniappOrderCancelRequest import MiniappOrderCancelRequest
from seven_jd.jd.api.rest.MiniappCiServiceExperienceRequest import MiniappCiServiceExperienceRequest
from seven_jd.jd.api.rest.OrderInfoDetailQueryN1Request import OrderInfoDetailQueryN1Request
from seven_jd.jd.api.rest.VcQualificationBySkuGetRequest import VcQualificationBySkuGetRequest
from seven_jd.jd.api.rest.OpenLocationRequest import OpenLocationRequest
from seven_jd.jd.api.rest.VcLibraryGetResouceUploadTokenRequest import VcLibraryGetResouceUploadTokenRequest
from seven_jd.jd.api.rest.OrderVenderRemarkQueryByOrderIdRequest import OrderVenderRemarkQueryByOrderIdRequest
from seven_jd.jd.api.rest.GroupMarketQuitGroupRequest import GroupMarketQuitGroupRequest
from seven_jd.jd.api.rest.EdiSdvVendorCommentReplySaveRequest import EdiSdvVendorCommentReplySaveRequest
from seven_jd.jd.api.rest.NewWareVenderSkusQueryRequest import NewWareVenderSkusQueryRequest
from seven_jd.jd.api.rest.MiniappOrderCreatedRequest import MiniappOrderCreatedRequest
from seven_jd.jd.api.rest.PromoUnitAddIsvActivityRequest import PromoUnitAddIsvActivityRequest
from seven_jd.jd.api.rest.PromoUnitGetVenderIsvActivityRequest import PromoUnitGetVenderIsvActivityRequest
from seven_jd.jd.api.rest.GetThirdPdfByOrderIdForVenderRequest import GetThirdPdfByOrderIdForVenderRequest
from seven_jd.jd.api.rest.PromoUnitGetActiveActivityRequest import PromoUnitGetActiveActivityRequest
from seven_jd.jd.api.rest.PopCrmShopGiftCloseShopGiftActivityCallBackRequest import PopCrmShopGiftCloseShopGiftActivityCallBackRequest
from seven_jd.jd.api.rest.PromoUnitModifyIsvActivityRequest import PromoUnitModifyIsvActivityRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceWriteCollectCouponRequest import InteractCenterApiServiceWriteCollectCouponRequest
from seven_jd.jd.api.rest.MiniappOrderRefundRequest import MiniappOrderRefundRequest
from seven_jd.jd.api.rest.ShorturlGenerateURLRequest import ShorturlGenerateURLRequest
from seven_jd.jd.api.rest.MarketToolCouponApiServiceCouponWriteOuterServiceCreateCouponRequest import MarketToolCouponApiServiceCouponWriteOuterServiceCreateCouponRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceWriteCollectBeanRequest import InteractCenterApiServiceWriteCollectBeanRequest
from seven_jd.jd.api.rest.SellerCouponWriteLockCouponRequest import SellerCouponWriteLockCouponRequest
from seven_jd.jd.api.rest.MiniappIsvCommitMiniAppCheckVersionRequest import MiniappIsvCommitMiniAppCheckVersionRequest
from seven_jd.jd.api.rest.FceAlphaGetVenderCarrierRequest import FceAlphaGetVenderCarrierRequest
from seven_jd.jd.api.rest.PromoUnitCloseIsvActivityRequest import PromoUnitCloseIsvActivityRequest
from seven_jd.jd.api.rest.PopPopCommentJsfServiceSaveCommentVoteRequest import PopPopCommentJsfServiceSaveCommentVoteRequest
from seven_jd.jd.api.rest.EptOrderGetorderinfobyidRequest import EptOrderGetorderinfobyidRequest
from seven_jd.jd.api.rest.PopPresellMyPresellServiceAddQualification4AppRequest import PopPresellMyPresellServiceAddQualification4AppRequest
from seven_jd.jd.api.rest.CarMemberSkuQueryCarBSkuListByShopIdRequest import CarMemberSkuQueryCarBSkuListByShopIdRequest
from seven_jd.jd.api.rest.MarketToolCouponApiServiceCouponReadOuterServiceQueryCouponPageRequest import MarketToolCouponApiServiceCouponReadOuterServiceQueryCouponPageRequest
from seven_jd.jd.api.rest.MarketBdpCartGetPinsBySkuIdRequest import MarketBdpCartGetPinsBySkuIdRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceWriteCollectPointsRequest import InteractCenterApiServiceWriteCollectPointsRequest
from seven_jd.jd.api.rest.ShorturlGenerateURLFastestRequest import ShorturlGenerateURLFastestRequest
from seven_jd.jd.api.rest.CmarketToolCouponApiServiceCouponWriteOuterServiceDeleteCouponRequest import CmarketToolCouponApiServiceCouponWriteOuterServiceDeleteCouponRequest
from seven_jd.jd.api.rest.MiniappOrderOrderInfoRequest import MiniappOrderOrderInfoRequest
from seven_jd.jd.api.rest.MarketToolCouponApiServiceCouponWriteOuterServiceCloseCouponRequest import MarketToolCouponApiServiceCouponWriteOuterServiceCloseCouponRequest
from seven_jd.jd.api.rest.UserCategory3InfoGetRequest import UserCategory3InfoGetRequest
from seven_jd.jd.api.rest.CrmMemberScanRequest import CrmMemberScanRequest
from seven_jd.jd.api.rest.MarketToolCouponApiServiceCouponReadOuterServiceQueryCouponDetailsRequest import MarketToolCouponApiServiceCouponReadOuterServiceQueryCouponDetailsRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceWriteWritePersonInfoRequest import InteractCenterApiServiceWriteWritePersonInfoRequest
from seven_jd.jd.api.rest.SelfOperationShopSearchApiServiceSearchRecomJsfServiceGetSearchRecomListRequest import SelfOperationShopSearchApiServiceSearchRecomJsfServiceGetSearchRecomListRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceReadFindRuleByIdAndTypeRequest import InteractCenterApiServiceReadFindRuleByIdAndTypeRequest
from seven_jd.jd.api.rest.SellerCouponWriteCreateRequest import SellerCouponWriteCreateRequest
from seven_jd.jd.api.rest.CreateMemberCardRequest import CreateMemberCardRequest
from seven_jd.jd.api.rest.WriteInteractUserCollectSinglePrizeRequest import WriteInteractUserCollectSinglePrizeRequest
from seven_jd.jd.api.rest.YipOrderGetOrderCustomeInfosRequest import YipOrderGetOrderCustomeInfosRequest
from seven_jd.jd.api.rest.SelfOperationShopSearchApiServiceSearchRecomJsfServiceCheckHotWordRequest import SelfOperationShopSearchApiServiceSearchRecomJsfServiceCheckHotWordRequest
from seven_jd.jd.api.rest.DetectionImagesRedLineDetectBatchRequest import DetectionImagesRedLineDetectBatchRequest
from seven_jd.jd.api.rest.PopOrderGetmobilelistRequest import PopOrderGetmobilelistRequest
from seven_jd.jd.api.rest.OrderOperateRequest import OrderOperateRequest
from seven_jd.jd.api.rest.PromoActivityListOperatelogRequest import PromoActivityListOperatelogRequest
from seven_jd.jd.api.rest.MiniappIsvCancelMiniAppExperVersionRequest import MiniappIsvCancelMiniAppExperVersionRequest
from seven_jd.jd.api.rest.SellerCouponWriteCloseRequest import SellerCouponWriteCloseRequest
from seven_jd.jd.api.rest.JosServiceWriteVenderJosShopGiftWriteServiceCloseActivityRequest import JosServiceWriteVenderJosShopGiftWriteServiceCloseActivityRequest
from seven_jd.jd.api.rest.OpenApplyAppointmentRequest import OpenApplyAppointmentRequest
from seven_jd.jd.api.rest.MarketDbpCartCartDataReadServiceGetCarSkuCountRequest import MarketDbpCartCartDataReadServiceGetCarSkuCountRequest
from seven_jd.jd.api.rest.WarehouseOutboundOrderQueryConditionRequest import WarehouseOutboundOrderQueryConditionRequest
from seven_jd.jd.api.rest.CrmGradeUpdateRequest import CrmGradeUpdateRequest
from seven_jd.jd.api.rest.KplOpenPolcenterUnsubscribeorderRequest import KplOpenPolcenterUnsubscribeorderRequest
from seven_jd.jd.api.rest.VcItemSaleAttributeSettingsGetRequest import VcItemSaleAttributeSettingsGetRequest
from seven_jd.jd.api.rest.CrmGradeGetRequest import CrmGradeGetRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceReadGetOtherCouponInfoRequest import InteractCenterApiServiceReadGetOtherCouponInfoRequest
from seven_jd.jd.api.rest.VenderAuthFindUserRequest import VenderAuthFindUserRequest
from seven_jd.jd.api.rest.ProductConfigSdkServiceSetProductConfigRequest import ProductConfigSdkServiceSetProductConfigRequest
from seven_jd.jd.api.rest.MiniappIsvOnlineMiniAppRelVersionRequest import MiniappIsvOnlineMiniAppRelVersionRequest
from seven_jd.jd.api.rest.CarMerberStoreListStoreInfoRequest import CarMerberStoreListStoreInfoRequest
from seven_jd.jd.api.rest.IsvSignWriteServiceSaveIsvSignStatisticsInfoRequest import IsvSignWriteServiceSaveIsvSignStatisticsInfoRequest
from seven_jd.jd.api.rest.PopCrmShopGiftCreateShopGiftRequest import PopCrmShopGiftCreateShopGiftRequest
from seven_jd.jd.api.rest.GroupMarketCloseActivityRequest import GroupMarketCloseActivityRequest
from seven_jd.jd.api.rest.DropshipDpsPartitionStockMaintainRequest import DropshipDpsPartitionStockMaintainRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceWriteCollectGiftRequest import InteractCenterApiServiceWriteCollectGiftRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceReadGetFreeCouponInfoRequest import InteractCenterApiServiceReadGetFreeCouponInfoRequest
from seven_jd.jd.api.rest.SelfOperationShopSearchApiServiceSearchRecomJsfServiceSaveRequest import SelfOperationShopSearchApiServiceSearchRecomJsfServiceSaveRequest
from seven_jd.jd.api.rest.PopAfsSoaRefundapplyQueryPageListRequest import PopAfsSoaRefundapplyQueryPageListRequest
from seven_jd.jd.api.rest.SellerCouponReadGetCouponListRequest import SellerCouponReadGetCouponListRequest
from seven_jd.jd.api.rest.PopVenderGetVenderStatusRequest import PopVenderGetVenderStatusRequest
from seven_jd.jd.api.rest.EdiSdvSalesForecastNumberSearchRequest import EdiSdvSalesForecastNumberSearchRequest
from seven_jd.jd.api.rest.SellerCouponReadGetCouponCountRequest import SellerCouponReadGetCouponCountRequest
from seven_jd.jd.api.rest.EdiSdvSalesForecastNumberGetRequest import EdiSdvSalesForecastNumberGetRequest
from seven_jd.jd.api.rest.EdiInventorySendRequest import EdiInventorySendRequest
from seven_jd.jd.api.rest.YipOrderAddCartForeignGoldRequest import YipOrderAddCartForeignGoldRequest
from seven_jd.jd.api.rest.MiniappCardNoRequest import MiniappCardNoRequest
from seven_jd.jd.api.rest.MiniappIsvGetDevopsPackIdByRequestUuidRequest import MiniappIsvGetDevopsPackIdByRequestUuidRequest
from seven_jd.jd.api.rest.IsvUploadBatchLogRequest import IsvUploadBatchLogRequest
from seven_jd.jd.api.rest.MiniappIsvDelMiniAppDevVersionRequest import MiniappIsvDelMiniAppDevVersionRequest
from seven_jd.jd.api.rest.JosSecretApiReportGetRequest import JosSecretApiReportGetRequest
from seven_jd.jd.api.rest.EdiSdvElectronicPolicySearchRequest import EdiSdvElectronicPolicySearchRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceReadGiftActivityResultReadServiceFindGiftInfoByIdRequest import InteractCenterApiServiceReadGiftActivityResultReadServiceFindGiftInfoByIdRequest
from seven_jd.jd.api.rest.VcAplsStockBatchGetProdStockInfoRequest import VcAplsStockBatchGetProdStockInfoRequest
from seven_jd.jd.api.rest.VenderVbinfoGetBasicVenderInfoByVenderIdRequest import VenderVbinfoGetBasicVenderInfoByVenderIdRequest
from seven_jd.jd.api.rest.GroupMarketEditActivityRequest import GroupMarketEditActivityRequest
from seven_jd.jd.api.rest.VcQueryshippackagepagelistRequest import VcQueryshippackagepagelistRequest
from seven_jd.jd.api.rest.GetUserEntryWechatGroupTrackRequest import GetUserEntryWechatGroupTrackRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceReadFindGiftRuleInfoByActivityIdRequest import InteractCenterApiServiceReadFindGiftRuleInfoByActivityIdRequest
from seven_jd.jd.api.rest.VssPromotionQueryunitpromopagelistRequest import VssPromotionQueryunitpromopagelistRequest
from seven_jd.jd.api.rest.QueryAddressListRequest import QueryAddressListRequest
from seven_jd.jd.api.rest.InteractCenterVenderWriteCloseActivityRequest import InteractCenterVenderWriteCloseActivityRequest
from seven_jd.jd.api.rest.PopVenderGetMemberBasicInfoRequest import PopVenderGetMemberBasicInfoRequest
from seven_jd.jd.api.rest.PopOrderFbpGetRequest import PopOrderFbpGetRequest
from seven_jd.jd.api.rest.SelfOperationShopSearchApiServiceSearchRecomJsfServiceGetSkuListRequest import SelfOperationShopSearchApiServiceSearchRecomJsfServiceGetSkuListRequest
from seven_jd.jd.api.rest.SelfOperationShopSearchApiServiceSearchRecomJsfServiceDeleteRequest import SelfOperationShopSearchApiServiceSearchRecomJsfServiceDeleteRequest
from seven_jd.jd.api.rest.ReadInteractUserFindSinglePrizeCollectInfoRequest import ReadInteractUserFindSinglePrizeCollectInfoRequest
from seven_jd.jd.api.rest.MarketBdpSaleVenderSkuRankQueryRequest import MarketBdpSaleVenderSkuRankQueryRequest
from seven_jd.jd.api.rest.DdPushRequest import DdPushRequest
from seven_jd.jd.api.rest.SellerPromotionCheckRequest import SellerPromotionCheckRequest
from seven_jd.jd.api.rest.SellerPromotionDeleteRequest import SellerPromotionDeleteRequest
from seven_jd.jd.api.rest.PopCustomerJosGetVenderCustomerByBindTimeRequest import PopCustomerJosGetVenderCustomerByBindTimeRequest
from seven_jd.jd.api.rest.MfaUserUnifiedAuthenticationRequest import MfaUserUnifiedAuthenticationRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceReadFindWorkingGiftActivityByVenderIdRequest import InteractCenterApiServiceReadFindWorkingGiftActivityByVenderIdRequest
from seven_jd.jd.api.rest.JosOauthRpcXidOpenId2XidRequest import JosOauthRpcXidOpenId2XidRequest
from seven_jd.jd.api.rest.JosOauthRpcXidPin2XidRequest import JosOauthRpcXidPin2XidRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceWriteCreateGiftActivityRequest import InteractCenterApiServiceWriteCreateGiftActivityRequest
from seven_jd.jd.api.rest.JingdongMiniappApiActivityMiniAppActivityApiUpdateActivityRequest import JingdongMiniappApiActivityMiniAppActivityApiUpdateActivityRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceWriteCloseGiftActivityRequest import InteractCenterApiServiceWriteCloseGiftActivityRequest
from seven_jd.jd.api.rest.PromoUnitCloseIsvSignActivityRequest import PromoUnitCloseIsvSignActivityRequest
from seven_jd.jd.api.rest.DropshipDpsSearchoutboundorderRequest import DropshipDpsSearchoutboundorderRequest
from seven_jd.jd.api.rest.VerifySaveRequest import VerifySaveRequest
from seven_jd.jd.api.rest.DropshipDpsSearchsingleorderRequest import DropshipDpsSearchsingleorderRequest
from seven_jd.jd.api.rest.VcItemDynamicFieldGaeaGetRequest import VcItemDynamicFieldGaeaGetRequest
from seven_jd.jd.api.rest.UserRelatedRpcI18nServiceGetOpenIdRequest import UserRelatedRpcI18nServiceGetOpenIdRequest
from seven_jd.jd.api.rest.MiniappIsvCommitMiniAppDevVersionRequest import MiniappIsvCommitMiniAppDevVersionRequest
from seven_jd.jd.api.rest.VcAplsStockUpdateProdStockInfoRequest import VcAplsStockUpdateProdStockInfoRequest
from seven_jd.jd.api.rest.GroupMarketGetMemberInfoRequest import GroupMarketGetMemberInfoRequest
from seven_jd.jd.api.rest.PopJmCenterUserGetEncryptPinNewRequest import PopJmCenterUserGetEncryptPinNewRequest
from seven_jd.jd.api.rest.GroupMarketJoinGroupRequest import GroupMarketJoinGroupRequest
from seven_jd.jd.api.rest.JosOauthRpcXidMixPin2XidRequest import JosOauthRpcXidMixPin2XidRequest
from seven_jd.jd.api.rest.IsvUploadDBOperationLogRequest import IsvUploadDBOperationLogRequest
from seven_jd.jd.api.rest.VenderCategoryGetValidCategoryResultByVenderIdRequest import VenderCategoryGetValidCategoryResultByVenderIdRequest
from seven_jd.jd.api.rest.GetPurchaseInfoRequest import GetPurchaseInfoRequest
from seven_jd.jd.api.rest.PopFwOrderListwithpageRequest import PopFwOrderListwithpageRequest
from seven_jd.jd.api.rest.DataVenderCommonQueryRequest import DataVenderCommonQueryRequest
from seven_jd.jd.api.rest.IsvUploadLoginLogRequest import IsvUploadLoginLogRequest
from seven_jd.jd.api.rest.CertUnlockRequest import CertUnlockRequest
from seven_jd.jd.api.rest.StockWriteUpdateSkuStockRequest import StockWriteUpdateSkuStockRequest
from seven_jd.jd.api.rest.SellerCouponWritePushCouponRequest import SellerCouponWritePushCouponRequest
from seven_jd.jd.api.rest.MiniActivityQueryRequest import MiniActivityQueryRequest
from seven_jd.jd.api.rest.WareProductUpdateQueryRequest import WareProductUpdateQueryRequest
from seven_jd.jd.api.rest.JmOrderGetPayUrlRequest import JmOrderGetPayUrlRequest
from seven_jd.jd.api.rest.PopOrderEnSearchRequest import PopOrderEnSearchRequest
from seven_jd.jd.api.rest.MiniappIsvGetMiniAppCheckVersionRequest import MiniappIsvGetMiniAppCheckVersionRequest
from seven_jd.jd.api.rest.PopOrderEnGetRequest import PopOrderEnGetRequest
from seven_jd.jd.api.rest.InteractCenterApiServiceReadFindCollectInfoRequest import InteractCenterApiServiceReadFindCollectInfoRequest
from seven_jd.jd.api.rest.ApplyRepealSaveRequest import ApplyRepealSaveRequest
from seven_jd.jd.api.rest.PreviewSaveRequest import PreviewSaveRequest
from seven_jd.jd.api.rest.TemplateReadFindTemplatesByVenderIdRequest import TemplateReadFindTemplatesByVenderIdRequest
from seven_jd.jd.api.rest.PrintingPrintDataSensitivePullDataRequest import PrintingPrintDataSensitivePullDataRequest
from seven_jd.jd.api.rest.TemplateReadFindTemplateByIdRequest import TemplateReadFindTemplateByIdRequest
from seven_jd.jd.api.rest.PrintingTemplateGetTemplateListRequest import PrintingTemplateGetTemplateListRequest
from seven_jd.jd.api.rest.StockReadFindSkuStockRequest import StockReadFindSkuStockRequest
from seven_jd.jd.api.rest.DetectionTextRedLineDetectRequest import DetectionTextRedLineDetectRequest
from seven_jd.jd.api.rest.IsvUploadThirdAppTransmitOrderInfoLogRequest import IsvUploadThirdAppTransmitOrderInfoLogRequest
from seven_jd.jd.api.rest.VenderShopcategoryGetShopCategorysByVenderIdRequest import VenderShopcategoryGetShopCategorysByVenderIdRequest
from seven_jd.jd.api.rest.IsvUploadOrderInfoLogRequest import IsvUploadOrderInfoLogRequest
from seven_jd.jd.api.rest.PointsJosSendPointsRequest import PointsJosSendPointsRequest
from seven_jd.jd.api.rest.PopVenderGetMemberLevelRequest import PopVenderGetMemberLevelRequest
from seven_jd.jd.api.rest.SellerPromotionV2GetRequest import SellerPromotionV2GetRequest
from seven_jd.jd.api.rest.PopGetCommentSummarysRequest import PopGetCommentSummarysRequest
from seven_jd.jd.api.rest.SellerPromotionV2ListRequest import SellerPromotionV2ListRequest
from seven_jd.jd.api.rest.SellerPromotionV2SkuListRequest import SellerPromotionV2SkuListRequest
from seven_jd.jd.api.rest.SellerPromotionV2SkuCountRequest import SellerPromotionV2SkuCountRequest
from seven_jd.jd.api.rest.PopCrmCustomerGetCustomerRequest import PopCrmCustomerGetCustomerRequest
from seven_jd.jd.api.rest.PopOrderFbpSearchRequest import PopOrderFbpSearchRequest
from seven_jd.jd.api.rest.VenderShopQueryRequest import VenderShopQueryRequest
from seven_jd.jd.api.rest.BrandBrandShopFacadeRequest import BrandBrandShopFacadeRequest
from seven_jd.jd.api.rest.TokenToPinCenterConverstionJmEncryptPinRequest import TokenToPinCenterConverstionJmEncryptPinRequest
from seven_jd.jd.api.rest.PopVenderGetVenderLevelRuleRequest import PopVenderGetVenderLevelRuleRequest
from seven_jd.jd.api.rest.PopOrderEncryptMobileNumRequest import PopOrderEncryptMobileNumRequest
from seven_jd.jd.api.rest.MarketServiceListGetRequest import MarketServiceListGetRequest
from seven_jd.jd.api.rest.MiniappApiActivityMiniAppActivityApiUpdateActivityStatusRequest import MiniappApiActivityMiniAppActivityApiUpdateActivityStatusRequest
from seven_jd.jd.api.rest.PopCrmGetMemeberDiscountRequest import PopCrmGetMemeberDiscountRequest
from seven_jd.jd.api.rest.SellerCouponWriteSendCouponRequest import SellerCouponWriteSendCouponRequest
from seven_jd.jd.api.rest.FwMarketPaymentoutRequest import FwMarketPaymentoutRequest
from seven_jd.jd.api.rest.VopAddressConvertFourAreaByDetailStrRequest import VopAddressConvertFourAreaByDetailStrRequest
from seven_jd.jd.api.rest.SellerPromotionV2ApproveRequest import SellerPromotionV2ApproveRequest
from seven_jd.jd.api.rest.MiniappApiActivityMiniAppActivityApiRequest import MiniappApiActivityMiniAppActivityApiRequest
from seven_jd.jd.api.rest.CategoryReadFindValuesByAttrIdUnlimitRequest import CategoryReadFindValuesByAttrIdUnlimitRequest
from seven_jd.jd.api.rest.SellerPromotionV2RemoveRequest import SellerPromotionV2RemoveRequest
from seven_jd.jd.api.rest.SkuReadFindSkuByIdRequest import SkuReadFindSkuByIdRequest
from seven_jd.jd.api.rest.QueryCid3ListByShopId2Request import QueryCid3ListByShopId2Request
from seven_jd.jd.api.rest.PopCrmGetCustomerAllInfoRequest import PopCrmGetCustomerAllInfoRequest
from seven_jd.jd.api.rest.JosMasterKeyGetRequest import JosMasterKeyGetRequest
from seven_jd.jd.api.rest.SellerVenderInfoGetRequest import SellerVenderInfoGetRequest
from seven_jd.jd.api.rest.SellerPromotionV2GetPromoLimitRequest import SellerPromotionV2GetPromoLimitRequest
from seven_jd.jd.api.rest.SkuReadSearchSkuListRequest import SkuReadSearchSkuListRequest
from seven_jd.jd.api.rest.ApplyAddMerchantsAddRequest import ApplyAddMerchantsAddRequest
from seven_jd.jd.api.rest.MarketChargeListGetRequest import MarketChargeListGetRequest
from seven_jd.jd.api.rest.GetDecryptPinRequest import GetDecryptPinRequest
from seven_jd.jd.api.rest.MiniappMixUserInfoRequest import MiniappMixUserInfoRequest
from seven_jd.jd.api.rest.AreasCityGetRequest import AreasCityGetRequest
from seven_jd.jd.api.rest.DropshipDpsModifyStockInfoRequest import DropshipDpsModifyStockInfoRequest
from seven_jd.jd.api.rest.VcItemAdvertiseApplyCreateRequest import VcItemAdvertiseApplyCreateRequest
from seven_jd.jd.api.rest.MarketToolCouponApiServiceCouponReadOuterServiceQueryWarePageRequest import MarketToolCouponApiServiceCouponReadOuterServiceQueryWarePageRequest
from seven_jd.jd.api.rest.SellerPromotionRemovePromoUsersRequest import SellerPromotionRemovePromoUsersRequest
from seven_jd.jd.api.rest.PromoActivityCountOperatelogRequest import PromoActivityCountOperatelogRequest
from seven_jd.jd.api.rest.DropshipDpsQueryStockInfoRequest import DropshipDpsQueryStockInfoRequest
from seven_jd.jd.api.rest.SellerPromotionCreateRequest import SellerPromotionCreateRequest
from seven_jd.jd.api.rest.PrintingPrintDataPullDataRequest import PrintingPrintDataPullDataRequest
from seven_jd.jd.api.rest.SellerPromotionAppendPromoUsersRequest import SellerPromotionAppendPromoUsersRequest
from seven_jd.jd.api.rest.MiniappRefundRequest import MiniappRefundRequest
from seven_jd.jd.api.rest.VcItemAdvertiseApplyGetRequest import VcItemAdvertiseApplyGetRequest
from seven_jd.jd.api.rest.PopCrmIsPointsEnabledRequest import PopCrmIsPointsEnabledRequest
from seven_jd.jd.api.rest.JdAddressFromAddressGetRequest import JdAddressFromAddressGetRequest
from seven_jd.jd.api.rest.VenderInfoQueryByPinRequest import VenderInfoQueryByPinRequest
from seven_jd.jd.api.rest.MiniappCiserviceYulanRequest import MiniappCiserviceYulanRequest
from seven_jd.jd.api.rest.MiniappCiserviceQueryRequest import MiniappCiserviceQueryRequest
from seven_jd.jd.api.rest.MarketToolCouponApiServiceCouponBaseReadOuterServiceInitBaseRuleInfoRequest import MarketToolCouponApiServiceCouponBaseReadOuterServiceInitBaseRuleInfoRequest
from seven_jd.jd.api.rest.MiniappMoneyCreateOrderRequest import MiniappMoneyCreateOrderRequest
from seven_jd.jd.api.rest.WareProductbigfieldGetRequest import WareProductbigfieldGetRequest
from seven_jd.jd.api.rest.EdiPoProGetRequest import EdiPoProGetRequest
from seven_jd.jd.api.rest.FollowVenderReadIsFollowByPinAndVidRequest import FollowVenderReadIsFollowByPinAndVidRequest
from seven_jd.jd.api.rest.VcItemAdvertiseApplyUpdateRequest import VcItemAdvertiseApplyUpdateRequest
from seven_jd.jd.api.rest.DropshipDpsPartitionStockIncrementmaintainRequest import DropshipDpsPartitionStockIncrementmaintainRequest
from seven_jd.jd.api.rest.AreasTownGetRequest import AreasTownGetRequest
from seven_jd.jd.api.rest.AreasCountyGetRequest import AreasCountyGetRequest
from seven_jd.jd.api.rest.SvcSettlementInfoRequest import SvcSettlementInfoRequest
from seven_jd.jd.api.rest.AreasProvinceGetRequest import AreasProvinceGetRequest
from seven_jd.jd.api.rest.NewWareBaseproductGetRequest import NewWareBaseproductGetRequest
from seven_jd.jd.api.rest.CertListQueryRequest import CertListQueryRequest
from seven_jd.jd.api.rest.PopJmCenterUserGetOpenIdRequest import PopJmCenterUserGetOpenIdRequest
from seven_jd.jd.api.rest.VcItemPurchasernameGetRequest import VcItemPurchasernameGetRequest
from seven_jd.jd.api.rest.GroupMarketQueryGroupByClusterIdRequest import GroupMarketQueryGroupByClusterIdRequest
from seven_jd.jd.api.rest.VcItemAdvertiseGetRequest import VcItemAdvertiseGetRequest
from seven_jd.jd.api.rest.DropshipDpsPartitionStockStoreQueryRequest import DropshipDpsPartitionStockStoreQueryRequest
from seven_jd.jd.api.rest.FollowVenderReadQueryForCountByVidRequest import FollowVenderReadQueryForCountByVidRequest
from seven_jd.jd.api.rest.VcItemAttrApplyUpdateRequest import VcItemAttrApplyUpdateRequest
from seven_jd.jd.api.rest.VcItemAttrApplyCreateRequest import VcItemAttrApplyCreateRequest
from seven_jd.jd.api.rest.FollowVenderWriteFollowByPinAndVidRequest import FollowVenderWriteFollowByPinAndVidRequest
from seven_jd.jd.api.rest.VcItemAttrApplyGetRequest import VcItemAttrApplyGetRequest
from seven_jd.jd.api.rest.VcItemAttrAppliesFindRequest import VcItemAttrAppliesFindRequest
from seven_jd.jd.api.rest.EdiSdvWarePerformancedataGetRequest import EdiSdvWarePerformancedataGetRequest
from seven_jd.jd.api.rest.VssReportJosSearchBrandPerformanceInfoRequest import VssReportJosSearchBrandPerformanceInfoRequest
from seven_jd.jd.api.rest.PopVideoInfoGetRequest import PopVideoInfoGetRequest
from seven_jd.jd.api.rest.VcItemAttrGetRequest import VcItemAttrGetRequest
from seven_jd.jd.api.rest.TemplateWriteBindWareRequest import TemplateWriteBindWareRequest
from seven_jd.jd.api.rest.JosVoucherInfoGetRequest import JosVoucherInfoGetRequest
from seven_jd.jd.api.rest.WarehouseInboundOrderQueryListRequest import WarehouseInboundOrderQueryListRequest
from seven_jd.jd.api.rest.IsvAddisvlogRequest import IsvAddisvlogRequest
from seven_jd.jd.api.rest.VcItemAdvertiseAppliesFindRequest import VcItemAdvertiseAppliesFindRequest
from seven_jd.jd.api.rest.SellerCouponReadFindCouponRequest import SellerCouponReadFindCouponRequest
from seven_jd.jd.api.rest.VcItemSaleunitsFindRequest import VcItemSaleunitsFindRequest
from seven_jd.jd.api.rest.WareReadSearchWare4ValidRequest import WareReadSearchWare4ValidRequest
from seven_jd.jd.api.rest.DataVenderPreciseRecomImageUploadRequest import DataVenderPreciseRecomImageUploadRequest
from seven_jd.jd.api.rest.VcItemSalernameGetRequest import VcItemSalernameGetRequest
from seven_jd.jd.api.rest.PopCrmGetVenderPointsRuleRequest import PopCrmGetVenderPointsRuleRequest
from seven_jd.jd.api.rest.NewWareProductsortattGetRequest import NewWareProductsortattGetRequest
from seven_jd.jd.api.rest.PopCrmGetPointsDetailByFlowRequest import PopCrmGetPointsDetailByFlowRequest
from seven_jd.jd.api.rest.WareReadFindWareByIdRequest import WareReadFindWareByIdRequest
from seven_jd.jd.api.rest.WarehouseOutboundOrderQueryListRequest import WarehouseOutboundOrderQueryListRequest
from seven_jd.jd.api.rest.WarehouseOutboundOrderQueryDetailWareRequest import WarehouseOutboundOrderQueryDetailWareRequest
from seven_jd.jd.api.rest.NewWareAttributeValuesQueryRequest import NewWareAttributeValuesQueryRequest
from seven_jd.jd.api.rest.InnovationProductReadGetSkuListRequest import InnovationProductReadGetSkuListRequest



from seven_jd.jd.api.base import RestApi

class EclpMasterInsertLogicalStockConfigRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.sellerNo = None
			self.deptNo = None
			self.sellerName = None
			self.deptName = None
			self.factor1No = None
			self.factor1Name = None
			self.factor2No = None
			self.factor2Name = None
			self.factor3No = None
			self.factor3Name = None
			self.factor4No = None
			self.factor4Name = None

		def getapiname(self):
			return 'jingdong.eclp.master.insertLogicalStockConfig'

			








from seven_jd.jd.api.base import RestApi

class CrmMemberSearchNewRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.customer_pin = None
			self.grade = None
			self.min_last_trade_time = None
			self.max_last_trade_time = None
			self.min_trade_count = None
			self.max_trade_count = None
			self.avg_price = None
			self.min_trade_amount = None
			self.current_page = None
			self.page_size = None
			self.open_id_buyer = None
			self.xid_buyer = None

		def getapiname(self):
			return 'jingdong.crm.member.searchNew'

			








from seven_jd.jd.api.base import RestApi

class LdopReceivePickuporderReceiveRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.pickupAddress = None
			self.pickupName = None
			self.pickupTel = None
			self.customerTel = None
			self.customerCode = None
			self.backAddress = None
			self.customerContract = None
			self.desp = None
			self.orderId = None
			self.weight = None
			self.remark = None
			self.volume = None
			self.valueAddService = None
			self.guaranteeValue = None
			self.guaranteeValueAmount = None
			self.pickupStartTime = None
			self.pickupEndTime = None
			self.productId = None
			self.productName = None
			self.productCount = None
			self.snCode = None
			self.skuAddService = None
			self.skuCheckOutShapes = None
			self.skuCheckAttachFile = None
			self.antiTearingCode = None
			self.promiseTimeType = None
			self.guaranteeSettleType = None
			self.packingSettleType = None
			self.freightSettleType = None
			self.allowedRepeatOrderType = None
			self.salePlatform = None
			self.settleType = None

		def getapiname(self):
			return 'jingdong.ldop.receive.pickuporder.receive'

			








from seven_jd.jd.api.base import RestApi

class EclpOrderAddOrderRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.isvUUID = None
			self.isvSource = None
			self.shopNo = None
			self.bdOwnerNo = None
			self.departmentNo = None
			self.warehouseNo = None
			self.shipperNo = None
			self.salesPlatformOrderNo = None
			self.salePlatformSource = None
			self.salesPlatformCreateTime = None
			self.soType = None
			self.consigneeName = None
			self.consigneeMobile = None
			self.consigneePhone = None
			self.consigneeEmail = None
			self.expectDate = None
			self.addressProvince = None
			self.addressCity = None
			self.addressCounty = None
			self.addressTown = None
			self.consigneeAddress = None
			self.consigneePostcode = None
			self.receivable = None
			self.consigneeRemark = None
			self.orderMark = None
			self.thirdWayBill = None
			self.packageMark = None
			self.businessType = None
			self.destinationCode = None
			self.destinationName = None
			self.sendWebsiteCode = None
			self.sendWebsiteName = None
			self.sendMode = None
			self.receiveMode = None
			self.appointDeliveryTime = None
			self.insuredPriceFlag = None
			self.insuredValue = None
			self.thirdPayment = None
			self.monthlyAccount = None
			self.shipment = None
			self.sellerRemark = None
			self.thirdSite = None
			self.gatherCenterName = None
			self.customsStatus = None
			self.customerName = None
			self.invoiceTitle = None
			self.invoiceContent = None
			self.goodsType = None
			self.goodsLevel = None
			self.customsPort = None
			self.billType = None
			self.orderPrice = None
			self.wlyInfo = None
			self.customerId = None
			self.urgency = None
			self.customerNo = None
			self.storeName = None
			self.invoiceState = None
			self.invoiceType = None
			self.invoiceNo = None
			self.invoiceTax = None
			self.bankName = None
			self.bankAccount = None
			self.address = None
			self.phoneNumber = None
			self.signType = None
			self.signIDCode = None
			self.supplierNo = None
			self.agingType = None
			self.sellerNote = None
			self.supervisionCode = None
			self.invoiceChecker = None
			self.paymentType = None
			self.saleType = None
			self.inStorageNo = None
			self.inStorageTime = None
			self.inStorageRemark = None
			self.grossReturnName = None
			self.grossReturnPhone = None
			self.grossReturnMobile = None
			self.grossReturnAddress = None
			self.isvPackTypeNo = None
			self.addrAnalysis = None
			self.printExtendInfo = None
			self.logicParam = None
			self.combineNo = None
			self.activationService = None
			self.randomInspection = None
			self.VIPDeliWarehouse = None
			self.customField = None
			self.longitude = None
			self.latitude = None
			self.agingProductType = None
			self.crossDockPriority = None
			self.isvCompanyNo = None
			self.orderPriority = None
			self.orderBatchNo = None
			self.orderBatchQty = None
			self.productCode = None
			self.vehicleType = None
			self.isvSoType = None
			self.checkDelivery = None
			self.isvSoTypeName = None
			self.quarantineCert = None
			self.deliveryService = None
			self.selfDeliverySiteId = None
			self.deliveryIntoWarehouse = None
			self.deliveryWarehouseType = None
			self.unPack = None
			self.deliveryBeforeCommand = None
			self.pickUpCode = None
			self.isvShopNo = None
			self.expecTransport = None
			self.inDependent = None
			self.storeBrand = None
			self.storeId = None
			self.unloadFlag = None
			self.relationNo = None
			self.deliveryProductCode = None
			self.sellerWarehouseNo = None
			self.peaceMindReceive = None
			self.yardInner = None
			self.warehouseProductNo = None
			self.deliveryProductNo = None
			self.payTime = None
			self.goodsNo = None
			self.skuGoodsLevel = None
			self.goodsName = None
			self.type = None
			self.unit = None
			self.remark = None
			self.rate = None
			self.amount = None
			self.price = None
			self.quantity = None
			self.pAttributes = None
			self.isvLotattrs = None
			self.isvGoodsNo = None
			self.installVenderId = None
			self.orderLine = None
			self.batAttrs = None
			self.productionDate = None
			self.expirationDate = None
			self.packBatchNo = None
			self.poNo = None
			self.lot = None
			self.serialNo = None
			self.jdPackageType = None
			self.serviceProductJson = None
			self.payAmount = None
			self.sellerGoodsRemark = None
			self.leftExpirationPercent = None
			self.leftExpirationPercentOperate = None
			self.batAttrRangeJson = None
			self.cloudPrintInfoJson = None

		def getapiname(self):
			return 'jingdong.eclp.order.addOrder'

			








from seven_jd.jd.api.base import RestApi

class FwMarketPaymentoutRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.requestNo = None
			self.activityId = None
			self.appId = None
			self.price = None
			self.isMainService = None
			self.serviceCycle = None
			self.skuId = None
			self.serviceCode = None
			self.orderNum = None
			self.itemCode = None
			self.outOrderId = None
			self.value1 = None
			self.resultPageType = None
			self.successUrl = None
			self.ip = None

		def getapiname(self):
			return 'jingdong.fw.market.paymentout'

			








from seven_jd.jd.api.base import RestApi

class WareReadSearchWare4ValidRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.wareId = None
			self.searchKey = None
			self.searchField = None
			self.categoryId = None
			self.shopCategoryIdLevel1 = None
			self.shopCategoryIdLevel2 = None
			self.templateId = None
			self.promiseId = None
			self.brandId = None
			self.featureKey = None
			self.featureValue = None
			self.wareStatusValue = None
			self.itemNum = None
			self.barCode = None
			self.colType = None
			self.startCreatedTime = None
			self.endCreatedTime = None
			self.startJdPrice = None
			self.endJdPrice = None
			self.startOnlineTime = None
			self.endOnlineTime = None
			self.startModifiedTime = None
			self.endModifiedTime = None
			self.startOfflineTime = None
			self.endOfflineTime = None
			self.startStockNum = None
			self.endStockNum = None
			self.orderField = None
			self.orderType = None
			self.pageNo = None
			self.pageSize = None
			self.transportId = None
			self.claim = None
			self.groupId = None
			self.multiCategoryId = None
			self.warePropKey = None
			self.warePropValue = None
			self.field = None

		def getapiname(self):
			return 'jingdong.ware.read.searchWare4Valid'

			








from seven_jd.jd.api.base import RestApi

class VcItemPrimaryPicCreateRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.sku_id = None
			self.image_list = None
			self.sku_id_long = None
			self.image_list_long = None
			self.sku_id_lucency = None
			self.image_list_lucency = None
			self.is_publishSchedule = None
			self.publish_time = None

		def getapiname(self):
			return 'jingdong.vc.item.primaryPic.create'

			








from seven_jd.jd.api.base import RestApi

class LdopDeliveryDeliveryPickupReceiveRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.josPin = None
			self.salePlat = None
			self.customerCode = None
			self.orderId = None
			self.thrOrderId = None
			self.senderName = None
			self.senderAddress = None
			self.senderTel = None
			self.senderMobile = None
			self.receiveName = None
			self.receiveAddress = None
			self.receiveTel = None
			self.receiveMobile = None
			self.province = None
			self.city = None
			self.county = None
			self.town = None
			self.packageCount = None
			self.weight = None
			self.vloumLong = None
			self.vloumWidth = None
			self.vloumHeight = None
			self.vloumn = None
			self.description = None
			self.goodsMoney = None
			self.collectionValue = None
			self.collectionMoney = None
			self.guaranteeValue = None
			self.guaranteeValueAmount = None
			self.signReturn = None
			self.aging = None
			self.goodsType = None
			self.warehouseCode = None
			self.remark = None
			self.idNumber = None
			self.addedService = None
			self.senderCompany = None
			self.receiveCompany = None
			self.senderIdNumber = None
			self.senderIdType = None
			self.sendAndPickupType = None
			self.backName = None
			self.backMobileNo = None
			self.backTelNo = None
			self.backProvinceName = None
			self.backCityName = None
			self.backCountry = None
			self.backTown = None
			self.backDetailAddress = None
			self.productType = None
			self.pickUpStartTime = None
			self.pickUpEndTime = None
			self.open_id_seller = None
			self.xid_seller = None
			self.customerTel = None
			self.backAddress = None
			self.customerContract = None
			self.pickupOrderId = None
			self.pickupWeight = None
			self.pickupRemark = None
			self.pickupVolume = None
			self.isGuaranteeValue = None
			self.pickupGuaranteeValueAmount = None
			self.pickupGoodsType = None
			self.pickupBizType = None
			self.valueAddService = None
			self.pickupSenderIdNumber = None
			self.pickupSenderIdType = None
			self.productId = None
			self.snCode = None
			self.productName = None
			self.productCount = None
			self.skuAddService = None
			self.skuCheckOutShapes = None
			self.skuCheckAttachFile = None
			self.skuServiceRequirements = None
			self.promiseTimeType = None
			self.guaranteeSettleType = None
			self.packingSettleType = None
			self.freightSettleType = None

		def getapiname(self):
			return 'jingdong.ldop.delivery.deliveryPickupReceive'

			








from seven_jd.jd.api.base import RestApi

class EclpGoodsQueryGoodsByPageAndTimeRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.deptNo = None
			self.isvGoodsNos = None
			self.goodsNos = None
			self.pageNo = None
			self.pageSize = None
			self.updateTimeStart = None
			self.updateTimeEnd = None

		def getapiname(self):
			return 'jingdong.eclp.goods.queryGoodsByPageAndTime'

			








from seven_jd.jd.api.base import RestApi

class EclpGoodsTransportGoodsSerialNumberRuleRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.deptNo = None
			self.goodsNo = None
			self.serialNumberLength = None
			self.serialNumberLeftvalue = None
			self.serialNumberLeftLength = None
			self.serialNumberSuffixLength = None
			self.suffixValue = None
			self.type = None
			self.ruleIndex = None
			self.ruleIndexEnd = None
			self.ruleIndexValue = None
			self.manageType = None
			self.sellerSnRuleNo = None
			self.serialRuleType = None

		def getapiname(self):
			return 'jingdong.eclp.goods.transportGoodsSerialNumberRule'

			








from seven_jd.jd.api.base import RestApi

class EclpCloudReceiveOrderInfoRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.machiningNo = None
			self.machiningType = None
			self.ownerNo = None
			self.skuNo = None
			self.productLevel = None
			self.qty = None
			self.destOwnerNo = None
			self.destSkuNo = None
			self.destQty = None
			self.destProductLevel = None
			self.warehouseNo = None
			self.tenantId = None

		def getapiname(self):
			return 'jingdong.eclp.cloud.receiveOrderInfo'

			








from seven_jd.jd.api.base import RestApi

class EclpRtwAddRtwOrderRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.eclpSoNo = None
			self.eclpRtwNo = None
			self.isvRtwNum = None
			self.warehouseNo = None
			self.logicParam = None
			self.reson = None
			self.orderType = None
			self.packageNo = None
			self.isvSoNo = None
			self.orderMark = None
			self.shipperName = None
			self.ownerNo = None
			self.orderInType = None
			self.receiveLevel = None
			self.sellerRemark = None
			self.salesMan = None
			self.salesBillingStaff = None
			self.drugElectronicSupervisionCode = None
			self.registerOrgNo = None
			self.registerOrgName = None
			self.customerName = None
			self.receivePriority = None
			self.sellerRtwType = None
			self.sellerRtwTypeName = None
			self.salesPlatformName = None
			self.spSoNo = None
			self.shopName = None
			self.workOrderNo = None
			self.senderName = None
			self.senderTelPhone = None
			self.senderMobilePhone = None
			self.customerId = None
			self.customField = None
			self.salesPlatformNo = None
			self.relatedOrderNo = None
			self.serialVersion = None
			self.serialBizType = None
			self.serialDetailMapJson = None
			self.isvGoodsNo = None
			self.planQty = None
			self.goodsLevel = None
			self.productionDate = None
			self.packageBatchNo = None
			self.eclpOutOrderNo = None
			self.sellerOutOrderNo = None
			self.unitPrice = None
			self.money = None
			self.mediumPackage = None
			self.bigPackage = None
			self.orderLine = None
			self.batAttrListJson = None
			self.deptGoodsNo = None
			self.planRtwReasonNo = None
			self.planRtwReasonDesc = None
			self.reserve1 = None

		def getapiname(self):
			return 'jingdong.eclp.rtw.addRtwOrder'

			








from seven_jd.jd.api.base import RestApi

class MarketToolCouponApiServiceCouponReadOuterServiceQueryCouponPageRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.creator = None
			self.newStatus = None
			self.skuIdStr = None
			self.bindType = None
			self.pageSize = None
			self.couponId = None
			self.wareChoseType = None
			self.delete = None
			self.spuId = None
			self.page = None
			self.beginTime = None
			self.endTime = None
			self.skuId = None
			self.couponTitle = None
			self.couponIdStr = None
			self.appName = None
			self.ip = None
			self.appId = None

		def getapiname(self):
			return 'jingdong.market.tool.coupon.api.service.CouponReadOuterService.queryCouponPage'

			








from seven_jd.jd.api.base import RestApi

class PopCrmShopGiftCreateShopGiftRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.name = None
			self.startDate = None
			self.endDate = None
			self.modelIds = None
			self.creator = None
			self.createChannel = None
			self.closeLink = None
			self.isvName = None
			self.activityLink = None
			self.requestPin = None
			self.isvValidate = None
			self.sendNumber = None
			self.open_id_seller = None
			self.xid_seller = None
			self.open_id_isv = None
			self.xid_isv = None
			self.discount = None
			self.quota = None
			self.validateDay = None
			self.prizeType = None
			self.sendCount = None

		def getapiname(self):
			return 'jingdong.pop.crm.shopGift.createShopGift'

			








from seven_jd.jd.api.base import RestApi

class IsvUploadThirdAppTransmitOrderInfoLogRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.app_name = None
			self.user_ip = None
			self.josAppKey = None
			self.device_id = None
			self.user_id = None
			self.order_ids = None
			self.sendto_url = None
			self.url = None
			self.time_stamp = None

		def getapiname(self):
			return 'jingdong.isv.uploadThirdAppTransmitOrderInfoLog'

			








from seven_jd.jd.api.base import RestApi

class RiskQueryServiceRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.param1 = None

		def getapiname(self):
			return 'jingdong.risk.QueryService'

			
	

class Param1(object):
		def __init__(self):
			"""
			"""
			self.appName = None
			self.time = None
			self.extendMap = None
			self.useType = None
			self.pin = None
			self.subSys = None
			self.open_id_buyer = None
			self.xid_buyer = None








from seven_jd.jd.api.base import RestApi

class VssPromotionQueryunitpromopagelistRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.ware_id = None
			self.promo_id = None
			self.promo_name = None
			self.create_time_begin = None
			self.create_time_end = None
			self.begin_time = None
			self.end_time = None
			self.promo_state = None
			self.audit_state = None
			self.page_index = None
			self.page_size = None

		def getapiname(self):
			return 'jingdong.vss.promotion.queryunitpromopagelist'

			








from seven_jd.jd.api.base import RestApi

class EclpStockSetShopStockFixedRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.requestId = None
			self.deptNo = None
			self.shopNo = None
			self.warehouseNo = None
			self.stockNum = None
			self.goodsNo = None
			self.shopType = None
			self.opUser = None

		def getapiname(self):
			return 'jingdong.eclp.stock.setShopStockFixed'

			








from seven_jd.jd.api.base import RestApi

class EclpMasterUpdateCustomerInfoRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.sellerNo = None
			self.deptNo = None
			self.customerNo = None
			self.customerName = None
			self.contacts = None
			self.phone = None
			self.customerEmail = None
			self.customerAddress = None
			self.customerType = None
			self.transitType = None
			self.warehouseName = None
			self.provinceName = None
			self.cityName = None
			self.countyName = None
			self.townName = None
			self.rection = None
			self.customerRemark = None
			self.licenseAddr = None
			self.licenseUnit = None
			self.licenseUnitNo = None
			self.warehouseNo = None
			self.sellerName = None
			self.medicineEnterpriseNature = None

		def getapiname(self):
			return 'jingdong.eclp.master.updateCustomerInfo'

			








from seven_jd.jd.api.base import RestApi

class LdopAlphaVendorRechargeQueryRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.vendorCode = None
			self.providerId = None
			self.branchCode = None
			self.startTime = None
			self.endTime = None

		def getapiname(self):
			return 'jingdong.ldop.alpha.vendor.recharge.query'

			








from seven_jd.jd.api.base import RestApi

class EtmsRangeCheckRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.salePlat = None
			self.customerCode = None
			self.orderId = None
			self.goodsType = None
			self.wareHouseCode = None
			self.receiveAddress = None
			self.transType = None
			self.senderProvinceId = None
			self.senderCityId = None
			self.senderCountyId = None
			self.senderTownId = None
			self.receiverProvinceId = None
			self.receiverCityId = None
			self.receiverCountyId = None
			self.receiverTownId = None
			self.sendTime = None
			self.isCod = None
			self.siteId = None
			self.siteName = None
			self.addedService = None
			self.promiseTimeType = None
			self.senderAddress = None
			self.pickupSiteId = None
			self.pickupSiteCode = None
			self.siteCode = None
			self.senderProvince = None
			self.senderCity = None
			self.senderCounty = None
			self.senderTown = None
			self.receiverProvince = None
			self.receiverCity = None
			self.receiverCounty = None
			self.receiverTown = None
			self.settleType = None
			self.requireDeliveryPresortMode = None

		def getapiname(self):
			return 'jingdong.etms.range.check'

			





